
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#include "config.h"
#include "gtk.h"
#include "gtkprivate.h"

G_GNUC_BEGIN_IGNORE_DEPRECATIONS
/* enumerations from "gtkassistant.h" */
GType
gtk_assistant_page_type_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_ASSISTANT_PAGE_CONTENT, "GTK_ASSISTANT_PAGE_CONTENT", "content" },
        { GTK_ASSISTANT_PAGE_INTRO, "GTK_ASSISTANT_PAGE_INTRO", "intro" },
        { GTK_ASSISTANT_PAGE_CONFIRM, "GTK_ASSISTANT_PAGE_CONFIRM", "confirm" },
        { GTK_ASSISTANT_PAGE_SUMMARY, "GTK_ASSISTANT_PAGE_SUMMARY", "summary" },
        { GTK_ASSISTANT_PAGE_PROGRESS, "GTK_ASSISTANT_PAGE_PROGRESS", "progress" },
        { GTK_ASSISTANT_PAGE_CUSTOM, "GTK_ASSISTANT_PAGE_CUSTOM", "custom" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkAssistantPageType"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkcellrenderer.h" */
GType
gtk_cell_renderer_state_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { GTK_CELL_RENDERER_SELECTED, "GTK_CELL_RENDERER_SELECTED", "selected" },
        { GTK_CELL_RENDERER_PRELIT, "GTK_CELL_RENDERER_PRELIT", "prelit" },
        { GTK_CELL_RENDERER_INSENSITIVE, "GTK_CELL_RENDERER_INSENSITIVE", "insensitive" },
        { GTK_CELL_RENDERER_SORTED, "GTK_CELL_RENDERER_SORTED", "sorted" },
        { GTK_CELL_RENDERER_FOCUSED, "GTK_CELL_RENDERER_FOCUSED", "focused" },
        { GTK_CELL_RENDERER_EXPANDABLE, "GTK_CELL_RENDERER_EXPANDABLE", "expandable" },
        { GTK_CELL_RENDERER_EXPANDED, "GTK_CELL_RENDERER_EXPANDED", "expanded" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_flags_register_static (g_intern_static_string ("GtkCellRendererState"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_cell_renderer_mode_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_CELL_RENDERER_MODE_INERT, "GTK_CELL_RENDERER_MODE_INERT", "inert" },
        { GTK_CELL_RENDERER_MODE_ACTIVATABLE, "GTK_CELL_RENDERER_MODE_ACTIVATABLE", "activatable" },
        { GTK_CELL_RENDERER_MODE_EDITABLE, "GTK_CELL_RENDERER_MODE_EDITABLE", "editable" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkCellRendererMode"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkcellrendereraccel.h" */
GType
gtk_cell_renderer_accel_mode_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_CELL_RENDERER_ACCEL_MODE_GTK, "GTK_CELL_RENDERER_ACCEL_MODE_GTK", "gtk" },
        { GTK_CELL_RENDERER_ACCEL_MODE_OTHER, "GTK_CELL_RENDERER_ACCEL_MODE_OTHER", "other" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkCellRendererAccelMode"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkdialog.h" */
GType
gtk_dialog_flags_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { GTK_DIALOG_MODAL, "GTK_DIALOG_MODAL", "modal" },
        { GTK_DIALOG_DESTROY_WITH_PARENT, "GTK_DIALOG_DESTROY_WITH_PARENT", "destroy-with-parent" },
        { GTK_DIALOG_USE_HEADER_BAR, "GTK_DIALOG_USE_HEADER_BAR", "use-header-bar" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_flags_register_static (g_intern_static_string ("GtkDialogFlags"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_response_type_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_RESPONSE_NONE, "GTK_RESPONSE_NONE", "none" },
        { GTK_RESPONSE_REJECT, "GTK_RESPONSE_REJECT", "reject" },
        { GTK_RESPONSE_ACCEPT, "GTK_RESPONSE_ACCEPT", "accept" },
        { GTK_RESPONSE_DELETE_EVENT, "GTK_RESPONSE_DELETE_EVENT", "delete-event" },
        { GTK_RESPONSE_OK, "GTK_RESPONSE_OK", "ok" },
        { GTK_RESPONSE_CANCEL, "GTK_RESPONSE_CANCEL", "cancel" },
        { GTK_RESPONSE_CLOSE, "GTK_RESPONSE_CLOSE", "close" },
        { GTK_RESPONSE_YES, "GTK_RESPONSE_YES", "yes" },
        { GTK_RESPONSE_NO, "GTK_RESPONSE_NO", "no" },
        { GTK_RESPONSE_APPLY, "GTK_RESPONSE_APPLY", "apply" },
        { GTK_RESPONSE_HELP, "GTK_RESPONSE_HELP", "help" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkResponseType"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkfilechooser.h" */
GType
gtk_file_chooser_action_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_FILE_CHOOSER_ACTION_OPEN, "GTK_FILE_CHOOSER_ACTION_OPEN", "open" },
        { GTK_FILE_CHOOSER_ACTION_SAVE, "GTK_FILE_CHOOSER_ACTION_SAVE", "save" },
        { GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER, "GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER", "select-folder" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkFileChooserAction"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_file_chooser_error_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_FILE_CHOOSER_ERROR_NONEXISTENT, "GTK_FILE_CHOOSER_ERROR_NONEXISTENT", "nonexistent" },
        { GTK_FILE_CHOOSER_ERROR_BAD_FILENAME, "GTK_FILE_CHOOSER_ERROR_BAD_FILENAME", "bad-filename" },
        { GTK_FILE_CHOOSER_ERROR_ALREADY_EXISTS, "GTK_FILE_CHOOSER_ERROR_ALREADY_EXISTS", "already-exists" },
        { GTK_FILE_CHOOSER_ERROR_INCOMPLETE_HOSTNAME, "GTK_FILE_CHOOSER_ERROR_INCOMPLETE_HOSTNAME", "incomplete-hostname" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkFileChooserError"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkfontchooser.h" */
GType
gtk_font_chooser_level_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { GTK_FONT_CHOOSER_LEVEL_FAMILY, "GTK_FONT_CHOOSER_LEVEL_FAMILY", "family" },
        { GTK_FONT_CHOOSER_LEVEL_STYLE, "GTK_FONT_CHOOSER_LEVEL_STYLE", "style" },
        { GTK_FONT_CHOOSER_LEVEL_SIZE, "GTK_FONT_CHOOSER_LEVEL_SIZE", "size" },
        { GTK_FONT_CHOOSER_LEVEL_VARIATIONS, "GTK_FONT_CHOOSER_LEVEL_VARIATIONS", "variations" },
        { GTK_FONT_CHOOSER_LEVEL_FEATURES, "GTK_FONT_CHOOSER_LEVEL_FEATURES", "features" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_flags_register_static (g_intern_static_string ("GtkFontChooserLevel"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkiconview.h" */
GType
gtk_icon_view_drop_position_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_ICON_VIEW_NO_DROP, "GTK_ICON_VIEW_NO_DROP", "no-drop" },
        { GTK_ICON_VIEW_DROP_INTO, "GTK_ICON_VIEW_DROP_INTO", "drop-into" },
        { GTK_ICON_VIEW_DROP_LEFT, "GTK_ICON_VIEW_DROP_LEFT", "drop-left" },
        { GTK_ICON_VIEW_DROP_RIGHT, "GTK_ICON_VIEW_DROP_RIGHT", "drop-right" },
        { GTK_ICON_VIEW_DROP_ABOVE, "GTK_ICON_VIEW_DROP_ABOVE", "drop-above" },
        { GTK_ICON_VIEW_DROP_BELOW, "GTK_ICON_VIEW_DROP_BELOW", "drop-below" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkIconViewDropPosition"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkmessagedialog.h" */
GType
gtk_buttons_type_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_BUTTONS_NONE, "GTK_BUTTONS_NONE", "none" },
        { GTK_BUTTONS_OK, "GTK_BUTTONS_OK", "ok" },
        { GTK_BUTTONS_CLOSE, "GTK_BUTTONS_CLOSE", "close" },
        { GTK_BUTTONS_CANCEL, "GTK_BUTTONS_CANCEL", "cancel" },
        { GTK_BUTTONS_YES_NO, "GTK_BUTTONS_YES_NO", "yes-no" },
        { GTK_BUTTONS_OK_CANCEL, "GTK_BUTTONS_OK_CANCEL", "ok-cancel" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkButtonsType"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkstylecontext.h" */
GType
gtk_style_context_print_flags_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { GTK_STYLE_CONTEXT_PRINT_NONE, "GTK_STYLE_CONTEXT_PRINT_NONE", "none" },
        { GTK_STYLE_CONTEXT_PRINT_RECURSE, "GTK_STYLE_CONTEXT_PRINT_RECURSE", "recurse" },
        { GTK_STYLE_CONTEXT_PRINT_SHOW_STYLE, "GTK_STYLE_CONTEXT_PRINT_SHOW_STYLE", "show-style" },
        { GTK_STYLE_CONTEXT_PRINT_SHOW_CHANGE, "GTK_STYLE_CONTEXT_PRINT_SHOW_CHANGE", "show-change" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_flags_register_static (g_intern_static_string ("GtkStyleContextPrintFlags"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtktreemodel.h" */
GType
gtk_tree_model_flags_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { GTK_TREE_MODEL_ITERS_PERSIST, "GTK_TREE_MODEL_ITERS_PERSIST", "iters-persist" },
        { GTK_TREE_MODEL_LIST_ONLY, "GTK_TREE_MODEL_LIST_ONLY", "list-only" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_flags_register_static (g_intern_static_string ("GtkTreeModelFlags"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtktreeview.h" */
GType
gtk_tree_view_drop_position_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_TREE_VIEW_DROP_BEFORE, "GTK_TREE_VIEW_DROP_BEFORE", "before" },
        { GTK_TREE_VIEW_DROP_AFTER, "GTK_TREE_VIEW_DROP_AFTER", "after" },
        { GTK_TREE_VIEW_DROP_INTO_OR_BEFORE, "GTK_TREE_VIEW_DROP_INTO_OR_BEFORE", "into-or-before" },
        { GTK_TREE_VIEW_DROP_INTO_OR_AFTER, "GTK_TREE_VIEW_DROP_INTO_OR_AFTER", "into-or-after" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkTreeViewDropPosition"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtktreeviewcolumn.h" */
GType
gtk_tree_view_column_sizing_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_TREE_VIEW_COLUMN_GROW_ONLY, "GTK_TREE_VIEW_COLUMN_GROW_ONLY", "grow-only" },
        { GTK_TREE_VIEW_COLUMN_AUTOSIZE, "GTK_TREE_VIEW_COLUMN_AUTOSIZE", "autosize" },
        { GTK_TREE_VIEW_COLUMN_FIXED, "GTK_TREE_VIEW_COLUMN_FIXED", "fixed" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkTreeViewColumnSizing"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkaboutdialog.h" */
GType
gtk_license_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_LICENSE_UNKNOWN, "GTK_LICENSE_UNKNOWN", "unknown" },
        { GTK_LICENSE_CUSTOM, "GTK_LICENSE_CUSTOM", "custom" },
        { GTK_LICENSE_GPL_2_0, "GTK_LICENSE_GPL_2_0", "gpl-2-0" },
        { GTK_LICENSE_GPL_3_0, "GTK_LICENSE_GPL_3_0", "gpl-3-0" },
        { GTK_LICENSE_LGPL_2_1, "GTK_LICENSE_LGPL_2_1", "lgpl-2-1" },
        { GTK_LICENSE_LGPL_3_0, "GTK_LICENSE_LGPL_3_0", "lgpl-3-0" },
        { GTK_LICENSE_BSD, "GTK_LICENSE_BSD", "bsd" },
        { GTK_LICENSE_MIT_X11, "GTK_LICENSE_MIT_X11", "mit-x11" },
        { GTK_LICENSE_ARTISTIC, "GTK_LICENSE_ARTISTIC", "artistic" },
        { GTK_LICENSE_GPL_2_0_ONLY, "GTK_LICENSE_GPL_2_0_ONLY", "gpl-2-0-only" },
        { GTK_LICENSE_GPL_3_0_ONLY, "GTK_LICENSE_GPL_3_0_ONLY", "gpl-3-0-only" },
        { GTK_LICENSE_LGPL_2_1_ONLY, "GTK_LICENSE_LGPL_2_1_ONLY", "lgpl-2-1-only" },
        { GTK_LICENSE_LGPL_3_0_ONLY, "GTK_LICENSE_LGPL_3_0_ONLY", "lgpl-3-0-only" },
        { GTK_LICENSE_AGPL_3_0, "GTK_LICENSE_AGPL_3_0", "agpl-3-0" },
        { GTK_LICENSE_AGPL_3_0_ONLY, "GTK_LICENSE_AGPL_3_0_ONLY", "agpl-3-0-only" },
        { GTK_LICENSE_BSD_3, "GTK_LICENSE_BSD_3", "bsd-3" },
        { GTK_LICENSE_APACHE_2_0, "GTK_LICENSE_APACHE_2_0", "apache-2-0" },
        { GTK_LICENSE_MPL_2_0, "GTK_LICENSE_MPL_2_0", "mpl-2-0" },
        { GTK_LICENSE_0BSD, "GTK_LICENSE_0BSD", "0bsd" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkLicense"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkaccessible.h" */
GType
gtk_accessible_platform_state_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_ACCESSIBLE_PLATFORM_STATE_FOCUSABLE, "GTK_ACCESSIBLE_PLATFORM_STATE_FOCUSABLE", "focusable" },
        { GTK_ACCESSIBLE_PLATFORM_STATE_FOCUSED, "GTK_ACCESSIBLE_PLATFORM_STATE_FOCUSED", "focused" },
        { GTK_ACCESSIBLE_PLATFORM_STATE_ACTIVE, "GTK_ACCESSIBLE_PLATFORM_STATE_ACTIVE", "active" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkAccessiblePlatformState"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkaccessibletext.h" */
GType
gtk_accessible_text_granularity_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_ACCESSIBLE_TEXT_GRANULARITY_CHARACTER, "GTK_ACCESSIBLE_TEXT_GRANULARITY_CHARACTER", "character" },
        { GTK_ACCESSIBLE_TEXT_GRANULARITY_WORD, "GTK_ACCESSIBLE_TEXT_GRANULARITY_WORD", "word" },
        { GTK_ACCESSIBLE_TEXT_GRANULARITY_SENTENCE, "GTK_ACCESSIBLE_TEXT_GRANULARITY_SENTENCE", "sentence" },
        { GTK_ACCESSIBLE_TEXT_GRANULARITY_LINE, "GTK_ACCESSIBLE_TEXT_GRANULARITY_LINE", "line" },
        { GTK_ACCESSIBLE_TEXT_GRANULARITY_PARAGRAPH, "GTK_ACCESSIBLE_TEXT_GRANULARITY_PARAGRAPH", "paragraph" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkAccessibleTextGranularity"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_accessible_text_content_change_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_ACCESSIBLE_TEXT_CONTENT_CHANGE_INSERT, "GTK_ACCESSIBLE_TEXT_CONTENT_CHANGE_INSERT", "insert" },
        { GTK_ACCESSIBLE_TEXT_CONTENT_CHANGE_REMOVE, "GTK_ACCESSIBLE_TEXT_CONTENT_CHANGE_REMOVE", "remove" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkAccessibleTextContentChange"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkapplication.h" */
GType
gtk_application_inhibit_flags_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { GTK_APPLICATION_INHIBIT_LOGOUT, "GTK_APPLICATION_INHIBIT_LOGOUT", "logout" },
        { GTK_APPLICATION_INHIBIT_SWITCH, "GTK_APPLICATION_INHIBIT_SWITCH", "switch" },
        { GTK_APPLICATION_INHIBIT_SUSPEND, "GTK_APPLICATION_INHIBIT_SUSPEND", "suspend" },
        { GTK_APPLICATION_INHIBIT_IDLE, "GTK_APPLICATION_INHIBIT_IDLE", "idle" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_flags_register_static (g_intern_static_string ("GtkApplicationInhibitFlags"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkbuilder.h" */
GType
gtk_builder_error_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_BUILDER_ERROR_INVALID_TYPE_FUNCTION, "GTK_BUILDER_ERROR_INVALID_TYPE_FUNCTION", "invalid-type-function" },
        { GTK_BUILDER_ERROR_UNHANDLED_TAG, "GTK_BUILDER_ERROR_UNHANDLED_TAG", "unhandled-tag" },
        { GTK_BUILDER_ERROR_MISSING_ATTRIBUTE, "GTK_BUILDER_ERROR_MISSING_ATTRIBUTE", "missing-attribute" },
        { GTK_BUILDER_ERROR_INVALID_ATTRIBUTE, "GTK_BUILDER_ERROR_INVALID_ATTRIBUTE", "invalid-attribute" },
        { GTK_BUILDER_ERROR_INVALID_TAG, "GTK_BUILDER_ERROR_INVALID_TAG", "invalid-tag" },
        { GTK_BUILDER_ERROR_MISSING_PROPERTY_VALUE, "GTK_BUILDER_ERROR_MISSING_PROPERTY_VALUE", "missing-property-value" },
        { GTK_BUILDER_ERROR_INVALID_VALUE, "GTK_BUILDER_ERROR_INVALID_VALUE", "invalid-value" },
        { GTK_BUILDER_ERROR_VERSION_MISMATCH, "GTK_BUILDER_ERROR_VERSION_MISMATCH", "version-mismatch" },
        { GTK_BUILDER_ERROR_DUPLICATE_ID, "GTK_BUILDER_ERROR_DUPLICATE_ID", "duplicate-id" },
        { GTK_BUILDER_ERROR_OBJECT_TYPE_REFUSED, "GTK_BUILDER_ERROR_OBJECT_TYPE_REFUSED", "object-type-refused" },
        { GTK_BUILDER_ERROR_TEMPLATE_MISMATCH, "GTK_BUILDER_ERROR_TEMPLATE_MISMATCH", "template-mismatch" },
        { GTK_BUILDER_ERROR_INVALID_PROPERTY, "GTK_BUILDER_ERROR_INVALID_PROPERTY", "invalid-property" },
        { GTK_BUILDER_ERROR_INVALID_SIGNAL, "GTK_BUILDER_ERROR_INVALID_SIGNAL", "invalid-signal" },
        { GTK_BUILDER_ERROR_INVALID_ID, "GTK_BUILDER_ERROR_INVALID_ID", "invalid-id" },
        { GTK_BUILDER_ERROR_INVALID_FUNCTION, "GTK_BUILDER_ERROR_INVALID_FUNCTION", "invalid-function" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkBuilderError"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkbuilderscope.h" */
GType
gtk_builder_closure_flags_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { GTK_BUILDER_CLOSURE_SWAPPED, "GTK_BUILDER_CLOSURE_SWAPPED", "swapped" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_flags_register_static (g_intern_static_string ("GtkBuilderClosureFlags"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkdebug.h" */
GType
gtk_debug_flags_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { GTK_DEBUG_TEXT, "GTK_DEBUG_TEXT", "text" },
        { GTK_DEBUG_TREE, "GTK_DEBUG_TREE", "tree" },
        { GTK_DEBUG_KEYBINDINGS, "GTK_DEBUG_KEYBINDINGS", "keybindings" },
        { GTK_DEBUG_MODULES, "GTK_DEBUG_MODULES", "modules" },
        { GTK_DEBUG_GEOMETRY, "GTK_DEBUG_GEOMETRY", "geometry" },
        { GTK_DEBUG_ICONTHEME, "GTK_DEBUG_ICONTHEME", "icontheme" },
        { GTK_DEBUG_PRINTING, "GTK_DEBUG_PRINTING", "printing" },
        { GTK_DEBUG_BUILDER, "GTK_DEBUG_BUILDER", "builder" },
        { GTK_DEBUG_SIZE_REQUEST, "GTK_DEBUG_SIZE_REQUEST", "size-request" },
        { GTK_DEBUG_NO_CSS_CACHE, "GTK_DEBUG_NO_CSS_CACHE", "no-css-cache" },
        { GTK_DEBUG_INTERACTIVE, "GTK_DEBUG_INTERACTIVE", "interactive" },
        { GTK_DEBUG_ACTIONS, "GTK_DEBUG_ACTIONS", "actions" },
        { GTK_DEBUG_LAYOUT, "GTK_DEBUG_LAYOUT", "layout" },
        { GTK_DEBUG_SNAPSHOT, "GTK_DEBUG_SNAPSHOT", "snapshot" },
        { GTK_DEBUG_CONSTRAINTS, "GTK_DEBUG_CONSTRAINTS", "constraints" },
        { GTK_DEBUG_BUILDER_OBJECTS, "GTK_DEBUG_BUILDER_OBJECTS", "builder-objects" },
        { GTK_DEBUG_A11Y, "GTK_DEBUG_A11Y", "a11y" },
        { GTK_DEBUG_ICONFALLBACK, "GTK_DEBUG_ICONFALLBACK", "iconfallback" },
        { GTK_DEBUG_INVERT_TEXT_DIR, "GTK_DEBUG_INVERT_TEXT_DIR", "invert-text-dir" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_flags_register_static (g_intern_static_string ("GtkDebugFlags"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkdialogerror.h" */
GType
gtk_dialog_error_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_DIALOG_ERROR_FAILED, "GTK_DIALOG_ERROR_FAILED", "failed" },
        { GTK_DIALOG_ERROR_CANCELLED, "GTK_DIALOG_ERROR_CANCELLED", "cancelled" },
        { GTK_DIALOG_ERROR_DISMISSED, "GTK_DIALOG_ERROR_DISMISSED", "dismissed" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkDialogError"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkeditable.h" */
GType
gtk_editable_properties_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_EDITABLE_PROP_TEXT, "GTK_EDITABLE_PROP_TEXT", "prop-text" },
        { GTK_EDITABLE_PROP_CURSOR_POSITION, "GTK_EDITABLE_PROP_CURSOR_POSITION", "prop-cursor-position" },
        { GTK_EDITABLE_PROP_SELECTION_BOUND, "GTK_EDITABLE_PROP_SELECTION_BOUND", "prop-selection-bound" },
        { GTK_EDITABLE_PROP_EDITABLE, "GTK_EDITABLE_PROP_EDITABLE", "prop-editable" },
        { GTK_EDITABLE_PROP_WIDTH_CHARS, "GTK_EDITABLE_PROP_WIDTH_CHARS", "prop-width-chars" },
        { GTK_EDITABLE_PROP_MAX_WIDTH_CHARS, "GTK_EDITABLE_PROP_MAX_WIDTH_CHARS", "prop-max-width-chars" },
        { GTK_EDITABLE_PROP_XALIGN, "GTK_EDITABLE_PROP_XALIGN", "prop-xalign" },
        { GTK_EDITABLE_PROP_ENABLE_UNDO, "GTK_EDITABLE_PROP_ENABLE_UNDO", "prop-enable-undo" },
        { GTK_EDITABLE_NUM_PROPERTIES, "GTK_EDITABLE_NUM_PROPERTIES", "num-properties" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkEditableProperties"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkentry.h" */
GType
gtk_entry_icon_position_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_ENTRY_ICON_PRIMARY, "GTK_ENTRY_ICON_PRIMARY", "primary" },
        { GTK_ENTRY_ICON_SECONDARY, "GTK_ENTRY_ICON_SECONDARY", "secondary" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkEntryIconPosition"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkenums.h" */
GType
gtk_align_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_ALIGN_FILL, "GTK_ALIGN_FILL", "fill" },
        { GTK_ALIGN_START, "GTK_ALIGN_START", "start" },
        { GTK_ALIGN_END, "GTK_ALIGN_END", "end" },
        { GTK_ALIGN_CENTER, "GTK_ALIGN_CENTER", "center" },
        { GTK_ALIGN_BASELINE_FILL, "GTK_ALIGN_BASELINE_FILL", "baseline-fill" },
        { GTK_ALIGN_BASELINE, "GTK_ALIGN_BASELINE", "baseline" },
        { GTK_ALIGN_BASELINE_CENTER, "GTK_ALIGN_BASELINE_CENTER", "baseline-center" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkAlign"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_arrow_type_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_ARROW_UP, "GTK_ARROW_UP", "up" },
        { GTK_ARROW_DOWN, "GTK_ARROW_DOWN", "down" },
        { GTK_ARROW_LEFT, "GTK_ARROW_LEFT", "left" },
        { GTK_ARROW_RIGHT, "GTK_ARROW_RIGHT", "right" },
        { GTK_ARROW_NONE, "GTK_ARROW_NONE", "none" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkArrowType"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_baseline_position_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_BASELINE_POSITION_TOP, "GTK_BASELINE_POSITION_TOP", "top" },
        { GTK_BASELINE_POSITION_CENTER, "GTK_BASELINE_POSITION_CENTER", "center" },
        { GTK_BASELINE_POSITION_BOTTOM, "GTK_BASELINE_POSITION_BOTTOM", "bottom" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkBaselinePosition"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_content_fit_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_CONTENT_FIT_FILL, "GTK_CONTENT_FIT_FILL", "fill" },
        { GTK_CONTENT_FIT_CONTAIN, "GTK_CONTENT_FIT_CONTAIN", "contain" },
        { GTK_CONTENT_FIT_COVER, "GTK_CONTENT_FIT_COVER", "cover" },
        { GTK_CONTENT_FIT_SCALE_DOWN, "GTK_CONTENT_FIT_SCALE_DOWN", "scale-down" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkContentFit"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_delete_type_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_DELETE_CHARS, "GTK_DELETE_CHARS", "chars" },
        { GTK_DELETE_WORD_ENDS, "GTK_DELETE_WORD_ENDS", "word-ends" },
        { GTK_DELETE_WORDS, "GTK_DELETE_WORDS", "words" },
        { GTK_DELETE_DISPLAY_LINES, "GTK_DELETE_DISPLAY_LINES", "display-lines" },
        { GTK_DELETE_DISPLAY_LINE_ENDS, "GTK_DELETE_DISPLAY_LINE_ENDS", "display-line-ends" },
        { GTK_DELETE_PARAGRAPH_ENDS, "GTK_DELETE_PARAGRAPH_ENDS", "paragraph-ends" },
        { GTK_DELETE_PARAGRAPHS, "GTK_DELETE_PARAGRAPHS", "paragraphs" },
        { GTK_DELETE_WHITESPACE, "GTK_DELETE_WHITESPACE", "whitespace" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkDeleteType"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_direction_type_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_DIR_TAB_FORWARD, "GTK_DIR_TAB_FORWARD", "tab-forward" },
        { GTK_DIR_TAB_BACKWARD, "GTK_DIR_TAB_BACKWARD", "tab-backward" },
        { GTK_DIR_UP, "GTK_DIR_UP", "up" },
        { GTK_DIR_DOWN, "GTK_DIR_DOWN", "down" },
        { GTK_DIR_LEFT, "GTK_DIR_LEFT", "left" },
        { GTK_DIR_RIGHT, "GTK_DIR_RIGHT", "right" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkDirectionType"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_icon_size_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_ICON_SIZE_INHERIT, "GTK_ICON_SIZE_INHERIT", "inherit" },
        { GTK_ICON_SIZE_NORMAL, "GTK_ICON_SIZE_NORMAL", "normal" },
        { GTK_ICON_SIZE_LARGE, "GTK_ICON_SIZE_LARGE", "large" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkIconSize"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_sensitivity_type_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_SENSITIVITY_AUTO, "GTK_SENSITIVITY_AUTO", "auto" },
        { GTK_SENSITIVITY_ON, "GTK_SENSITIVITY_ON", "on" },
        { GTK_SENSITIVITY_OFF, "GTK_SENSITIVITY_OFF", "off" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkSensitivityType"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_text_direction_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_TEXT_DIR_NONE, "GTK_TEXT_DIR_NONE", "none" },
        { GTK_TEXT_DIR_LTR, "GTK_TEXT_DIR_LTR", "ltr" },
        { GTK_TEXT_DIR_RTL, "GTK_TEXT_DIR_RTL", "rtl" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkTextDirection"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_justification_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_JUSTIFY_LEFT, "GTK_JUSTIFY_LEFT", "left" },
        { GTK_JUSTIFY_RIGHT, "GTK_JUSTIFY_RIGHT", "right" },
        { GTK_JUSTIFY_CENTER, "GTK_JUSTIFY_CENTER", "center" },
        { GTK_JUSTIFY_FILL, "GTK_JUSTIFY_FILL", "fill" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkJustification"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_list_tab_behavior_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_LIST_TAB_ALL, "GTK_LIST_TAB_ALL", "all" },
        { GTK_LIST_TAB_ITEM, "GTK_LIST_TAB_ITEM", "item" },
        { GTK_LIST_TAB_CELL, "GTK_LIST_TAB_CELL", "cell" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkListTabBehavior"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_list_scroll_flags_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { GTK_LIST_SCROLL_NONE, "GTK_LIST_SCROLL_NONE", "none" },
        { GTK_LIST_SCROLL_FOCUS, "GTK_LIST_SCROLL_FOCUS", "focus" },
        { GTK_LIST_SCROLL_SELECT, "GTK_LIST_SCROLL_SELECT", "select" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_flags_register_static (g_intern_static_string ("GtkListScrollFlags"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_message_type_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_MESSAGE_INFO, "GTK_MESSAGE_INFO", "info" },
        { GTK_MESSAGE_WARNING, "GTK_MESSAGE_WARNING", "warning" },
        { GTK_MESSAGE_QUESTION, "GTK_MESSAGE_QUESTION", "question" },
        { GTK_MESSAGE_ERROR, "GTK_MESSAGE_ERROR", "error" },
        { GTK_MESSAGE_OTHER, "GTK_MESSAGE_OTHER", "other" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkMessageType"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_movement_step_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_MOVEMENT_LOGICAL_POSITIONS, "GTK_MOVEMENT_LOGICAL_POSITIONS", "logical-positions" },
        { GTK_MOVEMENT_VISUAL_POSITIONS, "GTK_MOVEMENT_VISUAL_POSITIONS", "visual-positions" },
        { GTK_MOVEMENT_WORDS, "GTK_MOVEMENT_WORDS", "words" },
        { GTK_MOVEMENT_DISPLAY_LINES, "GTK_MOVEMENT_DISPLAY_LINES", "display-lines" },
        { GTK_MOVEMENT_DISPLAY_LINE_ENDS, "GTK_MOVEMENT_DISPLAY_LINE_ENDS", "display-line-ends" },
        { GTK_MOVEMENT_PARAGRAPHS, "GTK_MOVEMENT_PARAGRAPHS", "paragraphs" },
        { GTK_MOVEMENT_PARAGRAPH_ENDS, "GTK_MOVEMENT_PARAGRAPH_ENDS", "paragraph-ends" },
        { GTK_MOVEMENT_PAGES, "GTK_MOVEMENT_PAGES", "pages" },
        { GTK_MOVEMENT_BUFFER_ENDS, "GTK_MOVEMENT_BUFFER_ENDS", "buffer-ends" },
        { GTK_MOVEMENT_HORIZONTAL_PAGES, "GTK_MOVEMENT_HORIZONTAL_PAGES", "horizontal-pages" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkMovementStep"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_natural_wrap_mode_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_NATURAL_WRAP_INHERIT, "GTK_NATURAL_WRAP_INHERIT", "inherit" },
        { GTK_NATURAL_WRAP_NONE, "GTK_NATURAL_WRAP_NONE", "none" },
        { GTK_NATURAL_WRAP_WORD, "GTK_NATURAL_WRAP_WORD", "word" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkNaturalWrapMode"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_scroll_step_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_SCROLL_STEPS, "GTK_SCROLL_STEPS", "steps" },
        { GTK_SCROLL_PAGES, "GTK_SCROLL_PAGES", "pages" },
        { GTK_SCROLL_ENDS, "GTK_SCROLL_ENDS", "ends" },
        { GTK_SCROLL_HORIZONTAL_STEPS, "GTK_SCROLL_HORIZONTAL_STEPS", "horizontal-steps" },
        { GTK_SCROLL_HORIZONTAL_PAGES, "GTK_SCROLL_HORIZONTAL_PAGES", "horizontal-pages" },
        { GTK_SCROLL_HORIZONTAL_ENDS, "GTK_SCROLL_HORIZONTAL_ENDS", "horizontal-ends" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkScrollStep"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_orientation_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_ORIENTATION_HORIZONTAL, "GTK_ORIENTATION_HORIZONTAL", "horizontal" },
        { GTK_ORIENTATION_VERTICAL, "GTK_ORIENTATION_VERTICAL", "vertical" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkOrientation"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_overflow_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_OVERFLOW_VISIBLE, "GTK_OVERFLOW_VISIBLE", "visible" },
        { GTK_OVERFLOW_HIDDEN, "GTK_OVERFLOW_HIDDEN", "hidden" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkOverflow"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_pack_type_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_PACK_START, "GTK_PACK_START", "start" },
        { GTK_PACK_END, "GTK_PACK_END", "end" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkPackType"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_position_type_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_POS_LEFT, "GTK_POS_LEFT", "left" },
        { GTK_POS_RIGHT, "GTK_POS_RIGHT", "right" },
        { GTK_POS_TOP, "GTK_POS_TOP", "top" },
        { GTK_POS_BOTTOM, "GTK_POS_BOTTOM", "bottom" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkPositionType"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_scroll_type_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_SCROLL_NONE, "GTK_SCROLL_NONE", "none" },
        { GTK_SCROLL_JUMP, "GTK_SCROLL_JUMP", "jump" },
        { GTK_SCROLL_STEP_BACKWARD, "GTK_SCROLL_STEP_BACKWARD", "step-backward" },
        { GTK_SCROLL_STEP_FORWARD, "GTK_SCROLL_STEP_FORWARD", "step-forward" },
        { GTK_SCROLL_PAGE_BACKWARD, "GTK_SCROLL_PAGE_BACKWARD", "page-backward" },
        { GTK_SCROLL_PAGE_FORWARD, "GTK_SCROLL_PAGE_FORWARD", "page-forward" },
        { GTK_SCROLL_STEP_UP, "GTK_SCROLL_STEP_UP", "step-up" },
        { GTK_SCROLL_STEP_DOWN, "GTK_SCROLL_STEP_DOWN", "step-down" },
        { GTK_SCROLL_PAGE_UP, "GTK_SCROLL_PAGE_UP", "page-up" },
        { GTK_SCROLL_PAGE_DOWN, "GTK_SCROLL_PAGE_DOWN", "page-down" },
        { GTK_SCROLL_STEP_LEFT, "GTK_SCROLL_STEP_LEFT", "step-left" },
        { GTK_SCROLL_STEP_RIGHT, "GTK_SCROLL_STEP_RIGHT", "step-right" },
        { GTK_SCROLL_PAGE_LEFT, "GTK_SCROLL_PAGE_LEFT", "page-left" },
        { GTK_SCROLL_PAGE_RIGHT, "GTK_SCROLL_PAGE_RIGHT", "page-right" },
        { GTK_SCROLL_START, "GTK_SCROLL_START", "start" },
        { GTK_SCROLL_END, "GTK_SCROLL_END", "end" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkScrollType"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_selection_mode_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_SELECTION_NONE, "GTK_SELECTION_NONE", "none" },
        { GTK_SELECTION_SINGLE, "GTK_SELECTION_SINGLE", "single" },
        { GTK_SELECTION_BROWSE, "GTK_SELECTION_BROWSE", "browse" },
        { GTK_SELECTION_MULTIPLE, "GTK_SELECTION_MULTIPLE", "multiple" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkSelectionMode"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_wrap_mode_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_WRAP_NONE, "GTK_WRAP_NONE", "none" },
        { GTK_WRAP_CHAR, "GTK_WRAP_CHAR", "char" },
        { GTK_WRAP_WORD, "GTK_WRAP_WORD", "word" },
        { GTK_WRAP_WORD_CHAR, "GTK_WRAP_WORD_CHAR", "word-char" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkWrapMode"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_sort_type_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_SORT_ASCENDING, "GTK_SORT_ASCENDING", "ascending" },
        { GTK_SORT_DESCENDING, "GTK_SORT_DESCENDING", "descending" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkSortType"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_print_pages_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_PRINT_PAGES_ALL, "GTK_PRINT_PAGES_ALL", "all" },
        { GTK_PRINT_PAGES_CURRENT, "GTK_PRINT_PAGES_CURRENT", "current" },
        { GTK_PRINT_PAGES_RANGES, "GTK_PRINT_PAGES_RANGES", "ranges" },
        { GTK_PRINT_PAGES_SELECTION, "GTK_PRINT_PAGES_SELECTION", "selection" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkPrintPages"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_page_set_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_PAGE_SET_ALL, "GTK_PAGE_SET_ALL", "all" },
        { GTK_PAGE_SET_EVEN, "GTK_PAGE_SET_EVEN", "even" },
        { GTK_PAGE_SET_ODD, "GTK_PAGE_SET_ODD", "odd" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkPageSet"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_number_up_layout_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_NUMBER_UP_LAYOUT_LEFT_TO_RIGHT_TOP_TO_BOTTOM, "GTK_NUMBER_UP_LAYOUT_LEFT_TO_RIGHT_TOP_TO_BOTTOM", "lrtb" },
        { GTK_NUMBER_UP_LAYOUT_LEFT_TO_RIGHT_BOTTOM_TO_TOP, "GTK_NUMBER_UP_LAYOUT_LEFT_TO_RIGHT_BOTTOM_TO_TOP", "lrbt" },
        { GTK_NUMBER_UP_LAYOUT_RIGHT_TO_LEFT_TOP_TO_BOTTOM, "GTK_NUMBER_UP_LAYOUT_RIGHT_TO_LEFT_TOP_TO_BOTTOM", "rltb" },
        { GTK_NUMBER_UP_LAYOUT_RIGHT_TO_LEFT_BOTTOM_TO_TOP, "GTK_NUMBER_UP_LAYOUT_RIGHT_TO_LEFT_BOTTOM_TO_TOP", "rlbt" },
        { GTK_NUMBER_UP_LAYOUT_TOP_TO_BOTTOM_LEFT_TO_RIGHT, "GTK_NUMBER_UP_LAYOUT_TOP_TO_BOTTOM_LEFT_TO_RIGHT", "tblr" },
        { GTK_NUMBER_UP_LAYOUT_TOP_TO_BOTTOM_RIGHT_TO_LEFT, "GTK_NUMBER_UP_LAYOUT_TOP_TO_BOTTOM_RIGHT_TO_LEFT", "tbrl" },
        { GTK_NUMBER_UP_LAYOUT_BOTTOM_TO_TOP_LEFT_TO_RIGHT, "GTK_NUMBER_UP_LAYOUT_BOTTOM_TO_TOP_LEFT_TO_RIGHT", "btlr" },
        { GTK_NUMBER_UP_LAYOUT_BOTTOM_TO_TOP_RIGHT_TO_LEFT, "GTK_NUMBER_UP_LAYOUT_BOTTOM_TO_TOP_RIGHT_TO_LEFT", "btrl" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkNumberUpLayout"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_ordering_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_ORDERING_SMALLER, "GTK_ORDERING_SMALLER", "smaller" },
        { GTK_ORDERING_EQUAL, "GTK_ORDERING_EQUAL", "equal" },
        { GTK_ORDERING_LARGER, "GTK_ORDERING_LARGER", "larger" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkOrdering"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_page_orientation_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_PAGE_ORIENTATION_PORTRAIT, "GTK_PAGE_ORIENTATION_PORTRAIT", "portrait" },
        { GTK_PAGE_ORIENTATION_LANDSCAPE, "GTK_PAGE_ORIENTATION_LANDSCAPE", "landscape" },
        { GTK_PAGE_ORIENTATION_REVERSE_PORTRAIT, "GTK_PAGE_ORIENTATION_REVERSE_PORTRAIT", "reverse-portrait" },
        { GTK_PAGE_ORIENTATION_REVERSE_LANDSCAPE, "GTK_PAGE_ORIENTATION_REVERSE_LANDSCAPE", "reverse-landscape" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkPageOrientation"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_print_quality_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_PRINT_QUALITY_LOW, "GTK_PRINT_QUALITY_LOW", "low" },
        { GTK_PRINT_QUALITY_NORMAL, "GTK_PRINT_QUALITY_NORMAL", "normal" },
        { GTK_PRINT_QUALITY_HIGH, "GTK_PRINT_QUALITY_HIGH", "high" },
        { GTK_PRINT_QUALITY_DRAFT, "GTK_PRINT_QUALITY_DRAFT", "draft" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkPrintQuality"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_print_duplex_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_PRINT_DUPLEX_SIMPLEX, "GTK_PRINT_DUPLEX_SIMPLEX", "simplex" },
        { GTK_PRINT_DUPLEX_HORIZONTAL, "GTK_PRINT_DUPLEX_HORIZONTAL", "horizontal" },
        { GTK_PRINT_DUPLEX_VERTICAL, "GTK_PRINT_DUPLEX_VERTICAL", "vertical" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkPrintDuplex"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_unit_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_UNIT_NONE, "GTK_UNIT_NONE", "none" },
        { GTK_UNIT_POINTS, "GTK_UNIT_POINTS", "points" },
        { GTK_UNIT_INCH, "GTK_UNIT_INCH", "inch" },
        { GTK_UNIT_MM, "GTK_UNIT_MM", "mm" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkUnit"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_tree_view_grid_lines_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_TREE_VIEW_GRID_LINES_NONE, "GTK_TREE_VIEW_GRID_LINES_NONE", "none" },
        { GTK_TREE_VIEW_GRID_LINES_HORIZONTAL, "GTK_TREE_VIEW_GRID_LINES_HORIZONTAL", "horizontal" },
        { GTK_TREE_VIEW_GRID_LINES_VERTICAL, "GTK_TREE_VIEW_GRID_LINES_VERTICAL", "vertical" },
        { GTK_TREE_VIEW_GRID_LINES_BOTH, "GTK_TREE_VIEW_GRID_LINES_BOTH", "both" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkTreeViewGridLines"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_size_group_mode_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_SIZE_GROUP_NONE, "GTK_SIZE_GROUP_NONE", "none" },
        { GTK_SIZE_GROUP_HORIZONTAL, "GTK_SIZE_GROUP_HORIZONTAL", "horizontal" },
        { GTK_SIZE_GROUP_VERTICAL, "GTK_SIZE_GROUP_VERTICAL", "vertical" },
        { GTK_SIZE_GROUP_BOTH, "GTK_SIZE_GROUP_BOTH", "both" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkSizeGroupMode"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_size_request_mode_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_SIZE_REQUEST_HEIGHT_FOR_WIDTH, "GTK_SIZE_REQUEST_HEIGHT_FOR_WIDTH", "height-for-width" },
        { GTK_SIZE_REQUEST_WIDTH_FOR_HEIGHT, "GTK_SIZE_REQUEST_WIDTH_FOR_HEIGHT", "width-for-height" },
        { GTK_SIZE_REQUEST_CONSTANT_SIZE, "GTK_SIZE_REQUEST_CONSTANT_SIZE", "constant-size" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkSizeRequestMode"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_scrollable_policy_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_SCROLL_MINIMUM, "GTK_SCROLL_MINIMUM", "minimum" },
        { GTK_SCROLL_NATURAL, "GTK_SCROLL_NATURAL", "natural" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkScrollablePolicy"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_state_flags_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { GTK_STATE_FLAG_NORMAL, "GTK_STATE_FLAG_NORMAL", "normal" },
        { GTK_STATE_FLAG_ACTIVE, "GTK_STATE_FLAG_ACTIVE", "active" },
        { GTK_STATE_FLAG_PRELIGHT, "GTK_STATE_FLAG_PRELIGHT", "prelight" },
        { GTK_STATE_FLAG_SELECTED, "GTK_STATE_FLAG_SELECTED", "selected" },
        { GTK_STATE_FLAG_INSENSITIVE, "GTK_STATE_FLAG_INSENSITIVE", "insensitive" },
        { GTK_STATE_FLAG_INCONSISTENT, "GTK_STATE_FLAG_INCONSISTENT", "inconsistent" },
        { GTK_STATE_FLAG_FOCUSED, "GTK_STATE_FLAG_FOCUSED", "focused" },
        { GTK_STATE_FLAG_BACKDROP, "GTK_STATE_FLAG_BACKDROP", "backdrop" },
        { GTK_STATE_FLAG_DIR_LTR, "GTK_STATE_FLAG_DIR_LTR", "dir-ltr" },
        { GTK_STATE_FLAG_DIR_RTL, "GTK_STATE_FLAG_DIR_RTL", "dir-rtl" },
        { GTK_STATE_FLAG_LINK, "GTK_STATE_FLAG_LINK", "link" },
        { GTK_STATE_FLAG_VISITED, "GTK_STATE_FLAG_VISITED", "visited" },
        { GTK_STATE_FLAG_CHECKED, "GTK_STATE_FLAG_CHECKED", "checked" },
        { GTK_STATE_FLAG_DROP_ACTIVE, "GTK_STATE_FLAG_DROP_ACTIVE", "drop-active" },
        { GTK_STATE_FLAG_FOCUS_VISIBLE, "GTK_STATE_FLAG_FOCUS_VISIBLE", "focus-visible" },
        { GTK_STATE_FLAG_FOCUS_WITHIN, "GTK_STATE_FLAG_FOCUS_WITHIN", "focus-within" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_flags_register_static (g_intern_static_string ("GtkStateFlags"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_border_style_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_BORDER_STYLE_NONE, "GTK_BORDER_STYLE_NONE", "none" },
        { GTK_BORDER_STYLE_HIDDEN, "GTK_BORDER_STYLE_HIDDEN", "hidden" },
        { GTK_BORDER_STYLE_SOLID, "GTK_BORDER_STYLE_SOLID", "solid" },
        { GTK_BORDER_STYLE_INSET, "GTK_BORDER_STYLE_INSET", "inset" },
        { GTK_BORDER_STYLE_OUTSET, "GTK_BORDER_STYLE_OUTSET", "outset" },
        { GTK_BORDER_STYLE_DOTTED, "GTK_BORDER_STYLE_DOTTED", "dotted" },
        { GTK_BORDER_STYLE_DASHED, "GTK_BORDER_STYLE_DASHED", "dashed" },
        { GTK_BORDER_STYLE_DOUBLE, "GTK_BORDER_STYLE_DOUBLE", "double" },
        { GTK_BORDER_STYLE_GROOVE, "GTK_BORDER_STYLE_GROOVE", "groove" },
        { GTK_BORDER_STYLE_RIDGE, "GTK_BORDER_STYLE_RIDGE", "ridge" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkBorderStyle"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_level_bar_mode_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_LEVEL_BAR_MODE_CONTINUOUS, "GTK_LEVEL_BAR_MODE_CONTINUOUS", "continuous" },
        { GTK_LEVEL_BAR_MODE_DISCRETE, "GTK_LEVEL_BAR_MODE_DISCRETE", "discrete" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkLevelBarMode"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_input_purpose_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_INPUT_PURPOSE_FREE_FORM, "GTK_INPUT_PURPOSE_FREE_FORM", "free-form" },
        { GTK_INPUT_PURPOSE_ALPHA, "GTK_INPUT_PURPOSE_ALPHA", "alpha" },
        { GTK_INPUT_PURPOSE_DIGITS, "GTK_INPUT_PURPOSE_DIGITS", "digits" },
        { GTK_INPUT_PURPOSE_NUMBER, "GTK_INPUT_PURPOSE_NUMBER", "number" },
        { GTK_INPUT_PURPOSE_PHONE, "GTK_INPUT_PURPOSE_PHONE", "phone" },
        { GTK_INPUT_PURPOSE_URL, "GTK_INPUT_PURPOSE_URL", "url" },
        { GTK_INPUT_PURPOSE_EMAIL, "GTK_INPUT_PURPOSE_EMAIL", "email" },
        { GTK_INPUT_PURPOSE_NAME, "GTK_INPUT_PURPOSE_NAME", "name" },
        { GTK_INPUT_PURPOSE_PASSWORD, "GTK_INPUT_PURPOSE_PASSWORD", "password" },
        { GTK_INPUT_PURPOSE_PIN, "GTK_INPUT_PURPOSE_PIN", "pin" },
        { GTK_INPUT_PURPOSE_TERMINAL, "GTK_INPUT_PURPOSE_TERMINAL", "terminal" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkInputPurpose"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_input_hints_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { GTK_INPUT_HINT_NONE, "GTK_INPUT_HINT_NONE", "none" },
        { GTK_INPUT_HINT_SPELLCHECK, "GTK_INPUT_HINT_SPELLCHECK", "spellcheck" },
        { GTK_INPUT_HINT_NO_SPELLCHECK, "GTK_INPUT_HINT_NO_SPELLCHECK", "no-spellcheck" },
        { GTK_INPUT_HINT_WORD_COMPLETION, "GTK_INPUT_HINT_WORD_COMPLETION", "word-completion" },
        { GTK_INPUT_HINT_LOWERCASE, "GTK_INPUT_HINT_LOWERCASE", "lowercase" },
        { GTK_INPUT_HINT_UPPERCASE_CHARS, "GTK_INPUT_HINT_UPPERCASE_CHARS", "uppercase-chars" },
        { GTK_INPUT_HINT_UPPERCASE_WORDS, "GTK_INPUT_HINT_UPPERCASE_WORDS", "uppercase-words" },
        { GTK_INPUT_HINT_UPPERCASE_SENTENCES, "GTK_INPUT_HINT_UPPERCASE_SENTENCES", "uppercase-sentences" },
        { GTK_INPUT_HINT_INHIBIT_OSK, "GTK_INPUT_HINT_INHIBIT_OSK", "inhibit-osk" },
        { GTK_INPUT_HINT_VERTICAL_WRITING, "GTK_INPUT_HINT_VERTICAL_WRITING", "vertical-writing" },
        { GTK_INPUT_HINT_EMOJI, "GTK_INPUT_HINT_EMOJI", "emoji" },
        { GTK_INPUT_HINT_NO_EMOJI, "GTK_INPUT_HINT_NO_EMOJI", "no-emoji" },
        { GTK_INPUT_HINT_PRIVATE, "GTK_INPUT_HINT_PRIVATE", "private" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_flags_register_static (g_intern_static_string ("GtkInputHints"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_propagation_phase_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_PHASE_NONE, "GTK_PHASE_NONE", "none" },
        { GTK_PHASE_CAPTURE, "GTK_PHASE_CAPTURE", "capture" },
        { GTK_PHASE_BUBBLE, "GTK_PHASE_BUBBLE", "bubble" },
        { GTK_PHASE_TARGET, "GTK_PHASE_TARGET", "target" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkPropagationPhase"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_propagation_limit_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_LIMIT_NONE, "GTK_LIMIT_NONE", "none" },
        { GTK_LIMIT_SAME_NATIVE, "GTK_LIMIT_SAME_NATIVE", "same-native" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkPropagationLimit"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_event_sequence_state_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_EVENT_SEQUENCE_NONE, "GTK_EVENT_SEQUENCE_NONE", "none" },
        { GTK_EVENT_SEQUENCE_CLAIMED, "GTK_EVENT_SEQUENCE_CLAIMED", "claimed" },
        { GTK_EVENT_SEQUENCE_DENIED, "GTK_EVENT_SEQUENCE_DENIED", "denied" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkEventSequenceState"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_pan_direction_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_PAN_DIRECTION_LEFT, "GTK_PAN_DIRECTION_LEFT", "left" },
        { GTK_PAN_DIRECTION_RIGHT, "GTK_PAN_DIRECTION_RIGHT", "right" },
        { GTK_PAN_DIRECTION_UP, "GTK_PAN_DIRECTION_UP", "up" },
        { GTK_PAN_DIRECTION_DOWN, "GTK_PAN_DIRECTION_DOWN", "down" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkPanDirection"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_shortcut_scope_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_SHORTCUT_SCOPE_LOCAL, "GTK_SHORTCUT_SCOPE_LOCAL", "local" },
        { GTK_SHORTCUT_SCOPE_MANAGED, "GTK_SHORTCUT_SCOPE_MANAGED", "managed" },
        { GTK_SHORTCUT_SCOPE_GLOBAL, "GTK_SHORTCUT_SCOPE_GLOBAL", "global" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkShortcutScope"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_pick_flags_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { GTK_PICK_DEFAULT, "GTK_PICK_DEFAULT", "default" },
        { GTK_PICK_INSENSITIVE, "GTK_PICK_INSENSITIVE", "insensitive" },
        { GTK_PICK_NON_TARGETABLE, "GTK_PICK_NON_TARGETABLE", "non-targetable" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_flags_register_static (g_intern_static_string ("GtkPickFlags"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_constraint_relation_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_CONSTRAINT_RELATION_LE, "GTK_CONSTRAINT_RELATION_LE", "le" },
        { GTK_CONSTRAINT_RELATION_EQ, "GTK_CONSTRAINT_RELATION_EQ", "eq" },
        { GTK_CONSTRAINT_RELATION_GE, "GTK_CONSTRAINT_RELATION_GE", "ge" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkConstraintRelation"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_constraint_strength_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_CONSTRAINT_STRENGTH_REQUIRED, "GTK_CONSTRAINT_STRENGTH_REQUIRED", "required" },
        { GTK_CONSTRAINT_STRENGTH_STRONG, "GTK_CONSTRAINT_STRENGTH_STRONG", "strong" },
        { GTK_CONSTRAINT_STRENGTH_MEDIUM, "GTK_CONSTRAINT_STRENGTH_MEDIUM", "medium" },
        { GTK_CONSTRAINT_STRENGTH_WEAK, "GTK_CONSTRAINT_STRENGTH_WEAK", "weak" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkConstraintStrength"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_constraint_attribute_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_CONSTRAINT_ATTRIBUTE_NONE, "GTK_CONSTRAINT_ATTRIBUTE_NONE", "none" },
        { GTK_CONSTRAINT_ATTRIBUTE_LEFT, "GTK_CONSTRAINT_ATTRIBUTE_LEFT", "left" },
        { GTK_CONSTRAINT_ATTRIBUTE_RIGHT, "GTK_CONSTRAINT_ATTRIBUTE_RIGHT", "right" },
        { GTK_CONSTRAINT_ATTRIBUTE_TOP, "GTK_CONSTRAINT_ATTRIBUTE_TOP", "top" },
        { GTK_CONSTRAINT_ATTRIBUTE_BOTTOM, "GTK_CONSTRAINT_ATTRIBUTE_BOTTOM", "bottom" },
        { GTK_CONSTRAINT_ATTRIBUTE_START, "GTK_CONSTRAINT_ATTRIBUTE_START", "start" },
        { GTK_CONSTRAINT_ATTRIBUTE_END, "GTK_CONSTRAINT_ATTRIBUTE_END", "end" },
        { GTK_CONSTRAINT_ATTRIBUTE_WIDTH, "GTK_CONSTRAINT_ATTRIBUTE_WIDTH", "width" },
        { GTK_CONSTRAINT_ATTRIBUTE_HEIGHT, "GTK_CONSTRAINT_ATTRIBUTE_HEIGHT", "height" },
        { GTK_CONSTRAINT_ATTRIBUTE_CENTER_X, "GTK_CONSTRAINT_ATTRIBUTE_CENTER_X", "center-x" },
        { GTK_CONSTRAINT_ATTRIBUTE_CENTER_Y, "GTK_CONSTRAINT_ATTRIBUTE_CENTER_Y", "center-y" },
        { GTK_CONSTRAINT_ATTRIBUTE_BASELINE, "GTK_CONSTRAINT_ATTRIBUTE_BASELINE", "baseline" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkConstraintAttribute"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_constraint_vfl_parser_error_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_CONSTRAINT_VFL_PARSER_ERROR_INVALID_SYMBOL, "GTK_CONSTRAINT_VFL_PARSER_ERROR_INVALID_SYMBOL", "symbol" },
        { GTK_CONSTRAINT_VFL_PARSER_ERROR_INVALID_ATTRIBUTE, "GTK_CONSTRAINT_VFL_PARSER_ERROR_INVALID_ATTRIBUTE", "attribute" },
        { GTK_CONSTRAINT_VFL_PARSER_ERROR_INVALID_VIEW, "GTK_CONSTRAINT_VFL_PARSER_ERROR_INVALID_VIEW", "view" },
        { GTK_CONSTRAINT_VFL_PARSER_ERROR_INVALID_METRIC, "GTK_CONSTRAINT_VFL_PARSER_ERROR_INVALID_METRIC", "metric" },
        { GTK_CONSTRAINT_VFL_PARSER_ERROR_INVALID_PRIORITY, "GTK_CONSTRAINT_VFL_PARSER_ERROR_INVALID_PRIORITY", "priority" },
        { GTK_CONSTRAINT_VFL_PARSER_ERROR_INVALID_RELATION, "GTK_CONSTRAINT_VFL_PARSER_ERROR_INVALID_RELATION", "relation" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkConstraintVflParserError"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_system_setting_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_SYSTEM_SETTING_DPI, "GTK_SYSTEM_SETTING_DPI", "dpi" },
        { GTK_SYSTEM_SETTING_FONT_NAME, "GTK_SYSTEM_SETTING_FONT_NAME", "font-name" },
        { GTK_SYSTEM_SETTING_FONT_CONFIG, "GTK_SYSTEM_SETTING_FONT_CONFIG", "font-config" },
        { GTK_SYSTEM_SETTING_DISPLAY, "GTK_SYSTEM_SETTING_DISPLAY", "display" },
        { GTK_SYSTEM_SETTING_ICON_THEME, "GTK_SYSTEM_SETTING_ICON_THEME", "icon-theme" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkSystemSetting"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_symbolic_color_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_SYMBOLIC_COLOR_FOREGROUND, "GTK_SYMBOLIC_COLOR_FOREGROUND", "foreground" },
        { GTK_SYMBOLIC_COLOR_ERROR, "GTK_SYMBOLIC_COLOR_ERROR", "error" },
        { GTK_SYMBOLIC_COLOR_WARNING, "GTK_SYMBOLIC_COLOR_WARNING", "warning" },
        { GTK_SYMBOLIC_COLOR_SUCCESS, "GTK_SYMBOLIC_COLOR_SUCCESS", "success" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkSymbolicColor"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_accessible_role_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_ACCESSIBLE_ROLE_ALERT, "GTK_ACCESSIBLE_ROLE_ALERT", "alert" },
        { GTK_ACCESSIBLE_ROLE_ALERT_DIALOG, "GTK_ACCESSIBLE_ROLE_ALERT_DIALOG", "alert-dialog" },
        { GTK_ACCESSIBLE_ROLE_BANNER, "GTK_ACCESSIBLE_ROLE_BANNER", "banner" },
        { GTK_ACCESSIBLE_ROLE_BUTTON, "GTK_ACCESSIBLE_ROLE_BUTTON", "button" },
        { GTK_ACCESSIBLE_ROLE_CAPTION, "GTK_ACCESSIBLE_ROLE_CAPTION", "caption" },
        { GTK_ACCESSIBLE_ROLE_CELL, "GTK_ACCESSIBLE_ROLE_CELL", "cell" },
        { GTK_ACCESSIBLE_ROLE_CHECKBOX, "GTK_ACCESSIBLE_ROLE_CHECKBOX", "checkbox" },
        { GTK_ACCESSIBLE_ROLE_COLUMN_HEADER, "GTK_ACCESSIBLE_ROLE_COLUMN_HEADER", "column-header" },
        { GTK_ACCESSIBLE_ROLE_COMBO_BOX, "GTK_ACCESSIBLE_ROLE_COMBO_BOX", "combo-box" },
        { GTK_ACCESSIBLE_ROLE_COMMAND, "GTK_ACCESSIBLE_ROLE_COMMAND", "command" },
        { GTK_ACCESSIBLE_ROLE_COMPOSITE, "GTK_ACCESSIBLE_ROLE_COMPOSITE", "composite" },
        { GTK_ACCESSIBLE_ROLE_DIALOG, "GTK_ACCESSIBLE_ROLE_DIALOG", "dialog" },
        { GTK_ACCESSIBLE_ROLE_DOCUMENT, "GTK_ACCESSIBLE_ROLE_DOCUMENT", "document" },
        { GTK_ACCESSIBLE_ROLE_FEED, "GTK_ACCESSIBLE_ROLE_FEED", "feed" },
        { GTK_ACCESSIBLE_ROLE_FORM, "GTK_ACCESSIBLE_ROLE_FORM", "form" },
        { GTK_ACCESSIBLE_ROLE_GENERIC, "GTK_ACCESSIBLE_ROLE_GENERIC", "generic" },
        { GTK_ACCESSIBLE_ROLE_GRID, "GTK_ACCESSIBLE_ROLE_GRID", "grid" },
        { GTK_ACCESSIBLE_ROLE_GRID_CELL, "GTK_ACCESSIBLE_ROLE_GRID_CELL", "grid-cell" },
        { GTK_ACCESSIBLE_ROLE_GROUP, "GTK_ACCESSIBLE_ROLE_GROUP", "group" },
        { GTK_ACCESSIBLE_ROLE_HEADING, "GTK_ACCESSIBLE_ROLE_HEADING", "heading" },
        { GTK_ACCESSIBLE_ROLE_IMG, "GTK_ACCESSIBLE_ROLE_IMG", "img" },
        { GTK_ACCESSIBLE_ROLE_INPUT, "GTK_ACCESSIBLE_ROLE_INPUT", "input" },
        { GTK_ACCESSIBLE_ROLE_LABEL, "GTK_ACCESSIBLE_ROLE_LABEL", "label" },
        { GTK_ACCESSIBLE_ROLE_LANDMARK, "GTK_ACCESSIBLE_ROLE_LANDMARK", "landmark" },
        { GTK_ACCESSIBLE_ROLE_LEGEND, "GTK_ACCESSIBLE_ROLE_LEGEND", "legend" },
        { GTK_ACCESSIBLE_ROLE_LINK, "GTK_ACCESSIBLE_ROLE_LINK", "link" },
        { GTK_ACCESSIBLE_ROLE_LIST, "GTK_ACCESSIBLE_ROLE_LIST", "list" },
        { GTK_ACCESSIBLE_ROLE_LIST_BOX, "GTK_ACCESSIBLE_ROLE_LIST_BOX", "list-box" },
        { GTK_ACCESSIBLE_ROLE_LIST_ITEM, "GTK_ACCESSIBLE_ROLE_LIST_ITEM", "list-item" },
        { GTK_ACCESSIBLE_ROLE_LOG, "GTK_ACCESSIBLE_ROLE_LOG", "log" },
        { GTK_ACCESSIBLE_ROLE_MAIN, "GTK_ACCESSIBLE_ROLE_MAIN", "main" },
        { GTK_ACCESSIBLE_ROLE_MARQUEE, "GTK_ACCESSIBLE_ROLE_MARQUEE", "marquee" },
        { GTK_ACCESSIBLE_ROLE_MATH, "GTK_ACCESSIBLE_ROLE_MATH", "math" },
        { GTK_ACCESSIBLE_ROLE_METER, "GTK_ACCESSIBLE_ROLE_METER", "meter" },
        { GTK_ACCESSIBLE_ROLE_MENU, "GTK_ACCESSIBLE_ROLE_MENU", "menu" },
        { GTK_ACCESSIBLE_ROLE_MENU_BAR, "GTK_ACCESSIBLE_ROLE_MENU_BAR", "menu-bar" },
        { GTK_ACCESSIBLE_ROLE_MENU_ITEM, "GTK_ACCESSIBLE_ROLE_MENU_ITEM", "menu-item" },
        { GTK_ACCESSIBLE_ROLE_MENU_ITEM_CHECKBOX, "GTK_ACCESSIBLE_ROLE_MENU_ITEM_CHECKBOX", "menu-item-checkbox" },
        { GTK_ACCESSIBLE_ROLE_MENU_ITEM_RADIO, "GTK_ACCESSIBLE_ROLE_MENU_ITEM_RADIO", "menu-item-radio" },
        { GTK_ACCESSIBLE_ROLE_NAVIGATION, "GTK_ACCESSIBLE_ROLE_NAVIGATION", "navigation" },
        { GTK_ACCESSIBLE_ROLE_NONE, "GTK_ACCESSIBLE_ROLE_NONE", "none" },
        { GTK_ACCESSIBLE_ROLE_NOTE, "GTK_ACCESSIBLE_ROLE_NOTE", "note" },
        { GTK_ACCESSIBLE_ROLE_OPTION, "GTK_ACCESSIBLE_ROLE_OPTION", "option" },
        { GTK_ACCESSIBLE_ROLE_PRESENTATION, "GTK_ACCESSIBLE_ROLE_PRESENTATION", "presentation" },
        { GTK_ACCESSIBLE_ROLE_PROGRESS_BAR, "GTK_ACCESSIBLE_ROLE_PROGRESS_BAR", "progress-bar" },
        { GTK_ACCESSIBLE_ROLE_RADIO, "GTK_ACCESSIBLE_ROLE_RADIO", "radio" },
        { GTK_ACCESSIBLE_ROLE_RADIO_GROUP, "GTK_ACCESSIBLE_ROLE_RADIO_GROUP", "radio-group" },
        { GTK_ACCESSIBLE_ROLE_RANGE, "GTK_ACCESSIBLE_ROLE_RANGE", "range" },
        { GTK_ACCESSIBLE_ROLE_REGION, "GTK_ACCESSIBLE_ROLE_REGION", "region" },
        { GTK_ACCESSIBLE_ROLE_ROW, "GTK_ACCESSIBLE_ROLE_ROW", "row" },
        { GTK_ACCESSIBLE_ROLE_ROW_GROUP, "GTK_ACCESSIBLE_ROLE_ROW_GROUP", "row-group" },
        { GTK_ACCESSIBLE_ROLE_ROW_HEADER, "GTK_ACCESSIBLE_ROLE_ROW_HEADER", "row-header" },
        { GTK_ACCESSIBLE_ROLE_SCROLLBAR, "GTK_ACCESSIBLE_ROLE_SCROLLBAR", "scrollbar" },
        { GTK_ACCESSIBLE_ROLE_SEARCH, "GTK_ACCESSIBLE_ROLE_SEARCH", "search" },
        { GTK_ACCESSIBLE_ROLE_SEARCH_BOX, "GTK_ACCESSIBLE_ROLE_SEARCH_BOX", "search-box" },
        { GTK_ACCESSIBLE_ROLE_SECTION, "GTK_ACCESSIBLE_ROLE_SECTION", "section" },
        { GTK_ACCESSIBLE_ROLE_SECTION_HEAD, "GTK_ACCESSIBLE_ROLE_SECTION_HEAD", "section-head" },
        { GTK_ACCESSIBLE_ROLE_SELECT, "GTK_ACCESSIBLE_ROLE_SELECT", "select" },
        { GTK_ACCESSIBLE_ROLE_SEPARATOR, "GTK_ACCESSIBLE_ROLE_SEPARATOR", "separator" },
        { GTK_ACCESSIBLE_ROLE_SLIDER, "GTK_ACCESSIBLE_ROLE_SLIDER", "slider" },
        { GTK_ACCESSIBLE_ROLE_SPIN_BUTTON, "GTK_ACCESSIBLE_ROLE_SPIN_BUTTON", "spin-button" },
        { GTK_ACCESSIBLE_ROLE_STATUS, "GTK_ACCESSIBLE_ROLE_STATUS", "status" },
        { GTK_ACCESSIBLE_ROLE_STRUCTURE, "GTK_ACCESSIBLE_ROLE_STRUCTURE", "structure" },
        { GTK_ACCESSIBLE_ROLE_SWITCH, "GTK_ACCESSIBLE_ROLE_SWITCH", "switch" },
        { GTK_ACCESSIBLE_ROLE_TAB, "GTK_ACCESSIBLE_ROLE_TAB", "tab" },
        { GTK_ACCESSIBLE_ROLE_TABLE, "GTK_ACCESSIBLE_ROLE_TABLE", "table" },
        { GTK_ACCESSIBLE_ROLE_TAB_LIST, "GTK_ACCESSIBLE_ROLE_TAB_LIST", "tab-list" },
        { GTK_ACCESSIBLE_ROLE_TAB_PANEL, "GTK_ACCESSIBLE_ROLE_TAB_PANEL", "tab-panel" },
        { GTK_ACCESSIBLE_ROLE_TEXT_BOX, "GTK_ACCESSIBLE_ROLE_TEXT_BOX", "text-box" },
        { GTK_ACCESSIBLE_ROLE_TIME, "GTK_ACCESSIBLE_ROLE_TIME", "time" },
        { GTK_ACCESSIBLE_ROLE_TIMER, "GTK_ACCESSIBLE_ROLE_TIMER", "timer" },
        { GTK_ACCESSIBLE_ROLE_TOOLBAR, "GTK_ACCESSIBLE_ROLE_TOOLBAR", "toolbar" },
        { GTK_ACCESSIBLE_ROLE_TOOLTIP, "GTK_ACCESSIBLE_ROLE_TOOLTIP", "tooltip" },
        { GTK_ACCESSIBLE_ROLE_TREE, "GTK_ACCESSIBLE_ROLE_TREE", "tree" },
        { GTK_ACCESSIBLE_ROLE_TREE_GRID, "GTK_ACCESSIBLE_ROLE_TREE_GRID", "tree-grid" },
        { GTK_ACCESSIBLE_ROLE_TREE_ITEM, "GTK_ACCESSIBLE_ROLE_TREE_ITEM", "tree-item" },
        { GTK_ACCESSIBLE_ROLE_WIDGET, "GTK_ACCESSIBLE_ROLE_WIDGET", "widget" },
        { GTK_ACCESSIBLE_ROLE_WINDOW, "GTK_ACCESSIBLE_ROLE_WINDOW", "window" },
        { GTK_ACCESSIBLE_ROLE_TOGGLE_BUTTON, "GTK_ACCESSIBLE_ROLE_TOGGLE_BUTTON", "toggle-button" },
        { GTK_ACCESSIBLE_ROLE_APPLICATION, "GTK_ACCESSIBLE_ROLE_APPLICATION", "application" },
        { GTK_ACCESSIBLE_ROLE_PARAGRAPH, "GTK_ACCESSIBLE_ROLE_PARAGRAPH", "paragraph" },
        { GTK_ACCESSIBLE_ROLE_BLOCK_QUOTE, "GTK_ACCESSIBLE_ROLE_BLOCK_QUOTE", "block-quote" },
        { GTK_ACCESSIBLE_ROLE_ARTICLE, "GTK_ACCESSIBLE_ROLE_ARTICLE", "article" },
        { GTK_ACCESSIBLE_ROLE_COMMENT, "GTK_ACCESSIBLE_ROLE_COMMENT", "comment" },
        { GTK_ACCESSIBLE_ROLE_TERMINAL, "GTK_ACCESSIBLE_ROLE_TERMINAL", "terminal" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkAccessibleRole"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_accessible_state_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_ACCESSIBLE_STATE_BUSY, "GTK_ACCESSIBLE_STATE_BUSY", "busy" },
        { GTK_ACCESSIBLE_STATE_CHECKED, "GTK_ACCESSIBLE_STATE_CHECKED", "checked" },
        { GTK_ACCESSIBLE_STATE_DISABLED, "GTK_ACCESSIBLE_STATE_DISABLED", "disabled" },
        { GTK_ACCESSIBLE_STATE_EXPANDED, "GTK_ACCESSIBLE_STATE_EXPANDED", "expanded" },
        { GTK_ACCESSIBLE_STATE_HIDDEN, "GTK_ACCESSIBLE_STATE_HIDDEN", "hidden" },
        { GTK_ACCESSIBLE_STATE_INVALID, "GTK_ACCESSIBLE_STATE_INVALID", "invalid" },
        { GTK_ACCESSIBLE_STATE_PRESSED, "GTK_ACCESSIBLE_STATE_PRESSED", "pressed" },
        { GTK_ACCESSIBLE_STATE_SELECTED, "GTK_ACCESSIBLE_STATE_SELECTED", "selected" },
        { GTK_ACCESSIBLE_STATE_VISITED, "GTK_ACCESSIBLE_STATE_VISITED", "visited" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkAccessibleState"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_accessible_property_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_ACCESSIBLE_PROPERTY_AUTOCOMPLETE, "GTK_ACCESSIBLE_PROPERTY_AUTOCOMPLETE", "autocomplete" },
        { GTK_ACCESSIBLE_PROPERTY_DESCRIPTION, "GTK_ACCESSIBLE_PROPERTY_DESCRIPTION", "description" },
        { GTK_ACCESSIBLE_PROPERTY_HAS_POPUP, "GTK_ACCESSIBLE_PROPERTY_HAS_POPUP", "has-popup" },
        { GTK_ACCESSIBLE_PROPERTY_KEY_SHORTCUTS, "GTK_ACCESSIBLE_PROPERTY_KEY_SHORTCUTS", "key-shortcuts" },
        { GTK_ACCESSIBLE_PROPERTY_LABEL, "GTK_ACCESSIBLE_PROPERTY_LABEL", "label" },
        { GTK_ACCESSIBLE_PROPERTY_LEVEL, "GTK_ACCESSIBLE_PROPERTY_LEVEL", "level" },
        { GTK_ACCESSIBLE_PROPERTY_MODAL, "GTK_ACCESSIBLE_PROPERTY_MODAL", "modal" },
        { GTK_ACCESSIBLE_PROPERTY_MULTI_LINE, "GTK_ACCESSIBLE_PROPERTY_MULTI_LINE", "multi-line" },
        { GTK_ACCESSIBLE_PROPERTY_MULTI_SELECTABLE, "GTK_ACCESSIBLE_PROPERTY_MULTI_SELECTABLE", "multi-selectable" },
        { GTK_ACCESSIBLE_PROPERTY_ORIENTATION, "GTK_ACCESSIBLE_PROPERTY_ORIENTATION", "orientation" },
        { GTK_ACCESSIBLE_PROPERTY_PLACEHOLDER, "GTK_ACCESSIBLE_PROPERTY_PLACEHOLDER", "placeholder" },
        { GTK_ACCESSIBLE_PROPERTY_READ_ONLY, "GTK_ACCESSIBLE_PROPERTY_READ_ONLY", "read-only" },
        { GTK_ACCESSIBLE_PROPERTY_REQUIRED, "GTK_ACCESSIBLE_PROPERTY_REQUIRED", "required" },
        { GTK_ACCESSIBLE_PROPERTY_ROLE_DESCRIPTION, "GTK_ACCESSIBLE_PROPERTY_ROLE_DESCRIPTION", "role-description" },
        { GTK_ACCESSIBLE_PROPERTY_SORT, "GTK_ACCESSIBLE_PROPERTY_SORT", "sort" },
        { GTK_ACCESSIBLE_PROPERTY_VALUE_MAX, "GTK_ACCESSIBLE_PROPERTY_VALUE_MAX", "value-max" },
        { GTK_ACCESSIBLE_PROPERTY_VALUE_MIN, "GTK_ACCESSIBLE_PROPERTY_VALUE_MIN", "value-min" },
        { GTK_ACCESSIBLE_PROPERTY_VALUE_NOW, "GTK_ACCESSIBLE_PROPERTY_VALUE_NOW", "value-now" },
        { GTK_ACCESSIBLE_PROPERTY_VALUE_TEXT, "GTK_ACCESSIBLE_PROPERTY_VALUE_TEXT", "value-text" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkAccessibleProperty"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_accessible_relation_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_ACCESSIBLE_RELATION_ACTIVE_DESCENDANT, "GTK_ACCESSIBLE_RELATION_ACTIVE_DESCENDANT", "active-descendant" },
        { GTK_ACCESSIBLE_RELATION_COL_COUNT, "GTK_ACCESSIBLE_RELATION_COL_COUNT", "col-count" },
        { GTK_ACCESSIBLE_RELATION_COL_INDEX, "GTK_ACCESSIBLE_RELATION_COL_INDEX", "col-index" },
        { GTK_ACCESSIBLE_RELATION_COL_INDEX_TEXT, "GTK_ACCESSIBLE_RELATION_COL_INDEX_TEXT", "col-index-text" },
        { GTK_ACCESSIBLE_RELATION_COL_SPAN, "GTK_ACCESSIBLE_RELATION_COL_SPAN", "col-span" },
        { GTK_ACCESSIBLE_RELATION_CONTROLS, "GTK_ACCESSIBLE_RELATION_CONTROLS", "controls" },
        { GTK_ACCESSIBLE_RELATION_DESCRIBED_BY, "GTK_ACCESSIBLE_RELATION_DESCRIBED_BY", "described-by" },
        { GTK_ACCESSIBLE_RELATION_DETAILS, "GTK_ACCESSIBLE_RELATION_DETAILS", "details" },
        { GTK_ACCESSIBLE_RELATION_ERROR_MESSAGE, "GTK_ACCESSIBLE_RELATION_ERROR_MESSAGE", "error-message" },
        { GTK_ACCESSIBLE_RELATION_FLOW_TO, "GTK_ACCESSIBLE_RELATION_FLOW_TO", "flow-to" },
        { GTK_ACCESSIBLE_RELATION_LABELLED_BY, "GTK_ACCESSIBLE_RELATION_LABELLED_BY", "labelled-by" },
        { GTK_ACCESSIBLE_RELATION_OWNS, "GTK_ACCESSIBLE_RELATION_OWNS", "owns" },
        { GTK_ACCESSIBLE_RELATION_POS_IN_SET, "GTK_ACCESSIBLE_RELATION_POS_IN_SET", "pos-in-set" },
        { GTK_ACCESSIBLE_RELATION_ROW_COUNT, "GTK_ACCESSIBLE_RELATION_ROW_COUNT", "row-count" },
        { GTK_ACCESSIBLE_RELATION_ROW_INDEX, "GTK_ACCESSIBLE_RELATION_ROW_INDEX", "row-index" },
        { GTK_ACCESSIBLE_RELATION_ROW_INDEX_TEXT, "GTK_ACCESSIBLE_RELATION_ROW_INDEX_TEXT", "row-index-text" },
        { GTK_ACCESSIBLE_RELATION_ROW_SPAN, "GTK_ACCESSIBLE_RELATION_ROW_SPAN", "row-span" },
        { GTK_ACCESSIBLE_RELATION_SET_SIZE, "GTK_ACCESSIBLE_RELATION_SET_SIZE", "set-size" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkAccessibleRelation"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_accessible_tristate_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_ACCESSIBLE_TRISTATE_FALSE, "GTK_ACCESSIBLE_TRISTATE_FALSE", "false" },
        { GTK_ACCESSIBLE_TRISTATE_TRUE, "GTK_ACCESSIBLE_TRISTATE_TRUE", "true" },
        { GTK_ACCESSIBLE_TRISTATE_MIXED, "GTK_ACCESSIBLE_TRISTATE_MIXED", "mixed" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkAccessibleTristate"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_accessible_invalid_state_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_ACCESSIBLE_INVALID_FALSE, "GTK_ACCESSIBLE_INVALID_FALSE", "false" },
        { GTK_ACCESSIBLE_INVALID_TRUE, "GTK_ACCESSIBLE_INVALID_TRUE", "true" },
        { GTK_ACCESSIBLE_INVALID_GRAMMAR, "GTK_ACCESSIBLE_INVALID_GRAMMAR", "grammar" },
        { GTK_ACCESSIBLE_INVALID_SPELLING, "GTK_ACCESSIBLE_INVALID_SPELLING", "spelling" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkAccessibleInvalidState"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_accessible_autocomplete_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_ACCESSIBLE_AUTOCOMPLETE_NONE, "GTK_ACCESSIBLE_AUTOCOMPLETE_NONE", "none" },
        { GTK_ACCESSIBLE_AUTOCOMPLETE_INLINE, "GTK_ACCESSIBLE_AUTOCOMPLETE_INLINE", "inline" },
        { GTK_ACCESSIBLE_AUTOCOMPLETE_LIST, "GTK_ACCESSIBLE_AUTOCOMPLETE_LIST", "list" },
        { GTK_ACCESSIBLE_AUTOCOMPLETE_BOTH, "GTK_ACCESSIBLE_AUTOCOMPLETE_BOTH", "both" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkAccessibleAutocomplete"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_accessible_sort_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_ACCESSIBLE_SORT_NONE, "GTK_ACCESSIBLE_SORT_NONE", "none" },
        { GTK_ACCESSIBLE_SORT_ASCENDING, "GTK_ACCESSIBLE_SORT_ASCENDING", "ascending" },
        { GTK_ACCESSIBLE_SORT_DESCENDING, "GTK_ACCESSIBLE_SORT_DESCENDING", "descending" },
        { GTK_ACCESSIBLE_SORT_OTHER, "GTK_ACCESSIBLE_SORT_OTHER", "other" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkAccessibleSort"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_accessible_announcement_priority_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_ACCESSIBLE_ANNOUNCEMENT_PRIORITY_LOW, "GTK_ACCESSIBLE_ANNOUNCEMENT_PRIORITY_LOW", "low" },
        { GTK_ACCESSIBLE_ANNOUNCEMENT_PRIORITY_MEDIUM, "GTK_ACCESSIBLE_ANNOUNCEMENT_PRIORITY_MEDIUM", "medium" },
        { GTK_ACCESSIBLE_ANNOUNCEMENT_PRIORITY_HIGH, "GTK_ACCESSIBLE_ANNOUNCEMENT_PRIORITY_HIGH", "high" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkAccessibleAnnouncementPriority"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_popover_menu_flags_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { GTK_POPOVER_MENU_SLIDING, "GTK_POPOVER_MENU_SLIDING", "sliding" },
        { GTK_POPOVER_MENU_NESTED, "GTK_POPOVER_MENU_NESTED", "nested" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_flags_register_static (g_intern_static_string ("GtkPopoverMenuFlags"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkeventcontrollerscroll.h" */
GType
gtk_event_controller_scroll_flags_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { GTK_EVENT_CONTROLLER_SCROLL_NONE, "GTK_EVENT_CONTROLLER_SCROLL_NONE", "none" },
        { GTK_EVENT_CONTROLLER_SCROLL_VERTICAL, "GTK_EVENT_CONTROLLER_SCROLL_VERTICAL", "vertical" },
        { GTK_EVENT_CONTROLLER_SCROLL_HORIZONTAL, "GTK_EVENT_CONTROLLER_SCROLL_HORIZONTAL", "horizontal" },
        { GTK_EVENT_CONTROLLER_SCROLL_DISCRETE, "GTK_EVENT_CONTROLLER_SCROLL_DISCRETE", "discrete" },
        { GTK_EVENT_CONTROLLER_SCROLL_KINETIC, "GTK_EVENT_CONTROLLER_SCROLL_KINETIC", "kinetic" },
        { GTK_EVENT_CONTROLLER_SCROLL_BOTH_AXES, "GTK_EVENT_CONTROLLER_SCROLL_BOTH_AXES", "both-axes" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_flags_register_static (g_intern_static_string ("GtkEventControllerScrollFlags"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkfilter.h" */
GType
gtk_filter_match_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_FILTER_MATCH_SOME, "GTK_FILTER_MATCH_SOME", "some" },
        { GTK_FILTER_MATCH_NONE, "GTK_FILTER_MATCH_NONE", "none" },
        { GTK_FILTER_MATCH_ALL, "GTK_FILTER_MATCH_ALL", "all" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkFilterMatch"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_filter_change_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_FILTER_CHANGE_DIFFERENT, "GTK_FILTER_CHANGE_DIFFERENT", "different" },
        { GTK_FILTER_CHANGE_LESS_STRICT, "GTK_FILTER_CHANGE_LESS_STRICT", "less-strict" },
        { GTK_FILTER_CHANGE_MORE_STRICT, "GTK_FILTER_CHANGE_MORE_STRICT", "more-strict" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkFilterChange"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkfontdialogbutton.h" */
GType
gtk_font_level_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_FONT_LEVEL_FAMILY, "GTK_FONT_LEVEL_FAMILY", "family" },
        { GTK_FONT_LEVEL_FACE, "GTK_FONT_LEVEL_FACE", "face" },
        { GTK_FONT_LEVEL_FONT, "GTK_FONT_LEVEL_FONT", "font" },
        { GTK_FONT_LEVEL_FEATURES, "GTK_FONT_LEVEL_FEATURES", "features" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkFontLevel"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkgraphicsoffload.h" */
GType
gtk_graphics_offload_enabled_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_GRAPHICS_OFFLOAD_ENABLED, "GTK_GRAPHICS_OFFLOAD_ENABLED", "enabled" },
        { GTK_GRAPHICS_OFFLOAD_DISABLED, "GTK_GRAPHICS_OFFLOAD_DISABLED", "disabled" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkGraphicsOffloadEnabled"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkicontheme.h" */
GType
gtk_icon_lookup_flags_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { GTK_ICON_LOOKUP_FORCE_REGULAR, "GTK_ICON_LOOKUP_FORCE_REGULAR", "force-regular" },
        { GTK_ICON_LOOKUP_FORCE_SYMBOLIC, "GTK_ICON_LOOKUP_FORCE_SYMBOLIC", "force-symbolic" },
        { GTK_ICON_LOOKUP_PRELOAD, "GTK_ICON_LOOKUP_PRELOAD", "preload" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_flags_register_static (g_intern_static_string ("GtkIconLookupFlags"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_icon_theme_error_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_ICON_THEME_NOT_FOUND, "GTK_ICON_THEME_NOT_FOUND", "not-found" },
        { GTK_ICON_THEME_FAILED, "GTK_ICON_THEME_FAILED", "failed" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkIconThemeError"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkimage.h" */
GType
gtk_image_type_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_IMAGE_EMPTY, "GTK_IMAGE_EMPTY", "empty" },
        { GTK_IMAGE_ICON_NAME, "GTK_IMAGE_ICON_NAME", "icon-name" },
        { GTK_IMAGE_GICON, "GTK_IMAGE_GICON", "gicon" },
        { GTK_IMAGE_PAINTABLE, "GTK_IMAGE_PAINTABLE", "paintable" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkImageType"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkinscription.h" */
GType
gtk_inscription_overflow_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_INSCRIPTION_OVERFLOW_CLIP, "GTK_INSCRIPTION_OVERFLOW_CLIP", "clip" },
        { GTK_INSCRIPTION_OVERFLOW_ELLIPSIZE_START, "GTK_INSCRIPTION_OVERFLOW_ELLIPSIZE_START", "ellipsize-start" },
        { GTK_INSCRIPTION_OVERFLOW_ELLIPSIZE_MIDDLE, "GTK_INSCRIPTION_OVERFLOW_ELLIPSIZE_MIDDLE", "ellipsize-middle" },
        { GTK_INSCRIPTION_OVERFLOW_ELLIPSIZE_END, "GTK_INSCRIPTION_OVERFLOW_ELLIPSIZE_END", "ellipsize-end" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkInscriptionOverflow"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtknotebook.h" */
GType
gtk_notebook_tab_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_NOTEBOOK_TAB_FIRST, "GTK_NOTEBOOK_TAB_FIRST", "first" },
        { GTK_NOTEBOOK_TAB_LAST, "GTK_NOTEBOOK_TAB_LAST", "last" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkNotebookTab"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkpadcontroller.h" */
GType
gtk_pad_action_type_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_PAD_ACTION_BUTTON, "GTK_PAD_ACTION_BUTTON", "button" },
        { GTK_PAD_ACTION_RING, "GTK_PAD_ACTION_RING", "ring" },
        { GTK_PAD_ACTION_STRIP, "GTK_PAD_ACTION_STRIP", "strip" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkPadActionType"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkrecentmanager.h" */
GType
gtk_recent_manager_error_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_RECENT_MANAGER_ERROR_NOT_FOUND, "GTK_RECENT_MANAGER_ERROR_NOT_FOUND", "not-found" },
        { GTK_RECENT_MANAGER_ERROR_INVALID_URI, "GTK_RECENT_MANAGER_ERROR_INVALID_URI", "invalid-uri" },
        { GTK_RECENT_MANAGER_ERROR_INVALID_ENCODING, "GTK_RECENT_MANAGER_ERROR_INVALID_ENCODING", "invalid-encoding" },
        { GTK_RECENT_MANAGER_ERROR_NOT_REGISTERED, "GTK_RECENT_MANAGER_ERROR_NOT_REGISTERED", "not-registered" },
        { GTK_RECENT_MANAGER_ERROR_READ, "GTK_RECENT_MANAGER_ERROR_READ", "read" },
        { GTK_RECENT_MANAGER_ERROR_WRITE, "GTK_RECENT_MANAGER_ERROR_WRITE", "write" },
        { GTK_RECENT_MANAGER_ERROR_UNKNOWN, "GTK_RECENT_MANAGER_ERROR_UNKNOWN", "unknown" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkRecentManagerError"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkrevealer.h" */
GType
gtk_revealer_transition_type_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_REVEALER_TRANSITION_TYPE_NONE, "GTK_REVEALER_TRANSITION_TYPE_NONE", "none" },
        { GTK_REVEALER_TRANSITION_TYPE_CROSSFADE, "GTK_REVEALER_TRANSITION_TYPE_CROSSFADE", "crossfade" },
        { GTK_REVEALER_TRANSITION_TYPE_SLIDE_RIGHT, "GTK_REVEALER_TRANSITION_TYPE_SLIDE_RIGHT", "slide-right" },
        { GTK_REVEALER_TRANSITION_TYPE_SLIDE_LEFT, "GTK_REVEALER_TRANSITION_TYPE_SLIDE_LEFT", "slide-left" },
        { GTK_REVEALER_TRANSITION_TYPE_SLIDE_UP, "GTK_REVEALER_TRANSITION_TYPE_SLIDE_UP", "slide-up" },
        { GTK_REVEALER_TRANSITION_TYPE_SLIDE_DOWN, "GTK_REVEALER_TRANSITION_TYPE_SLIDE_DOWN", "slide-down" },
        { GTK_REVEALER_TRANSITION_TYPE_SWING_RIGHT, "GTK_REVEALER_TRANSITION_TYPE_SWING_RIGHT", "swing-right" },
        { GTK_REVEALER_TRANSITION_TYPE_SWING_LEFT, "GTK_REVEALER_TRANSITION_TYPE_SWING_LEFT", "swing-left" },
        { GTK_REVEALER_TRANSITION_TYPE_SWING_UP, "GTK_REVEALER_TRANSITION_TYPE_SWING_UP", "swing-up" },
        { GTK_REVEALER_TRANSITION_TYPE_SWING_DOWN, "GTK_REVEALER_TRANSITION_TYPE_SWING_DOWN", "swing-down" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkRevealerTransitionType"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkscrolledwindow.h" */
GType
gtk_corner_type_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_CORNER_TOP_LEFT, "GTK_CORNER_TOP_LEFT", "top-left" },
        { GTK_CORNER_BOTTOM_LEFT, "GTK_CORNER_BOTTOM_LEFT", "bottom-left" },
        { GTK_CORNER_TOP_RIGHT, "GTK_CORNER_TOP_RIGHT", "top-right" },
        { GTK_CORNER_BOTTOM_RIGHT, "GTK_CORNER_BOTTOM_RIGHT", "bottom-right" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkCornerType"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_policy_type_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_POLICY_ALWAYS, "GTK_POLICY_ALWAYS", "always" },
        { GTK_POLICY_AUTOMATIC, "GTK_POLICY_AUTOMATIC", "automatic" },
        { GTK_POLICY_NEVER, "GTK_POLICY_NEVER", "never" },
        { GTK_POLICY_EXTERNAL, "GTK_POLICY_EXTERNAL", "external" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkPolicyType"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkshortcutaction.h" */
GType
gtk_shortcut_action_flags_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { GTK_SHORTCUT_ACTION_EXCLUSIVE, "GTK_SHORTCUT_ACTION_EXCLUSIVE", "exclusive" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_flags_register_static (g_intern_static_string ("GtkShortcutActionFlags"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkshortcutsshortcut.h" */
GType
gtk_shortcut_type_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_SHORTCUT_ACCELERATOR, "GTK_SHORTCUT_ACCELERATOR", "accelerator" },
        { GTK_SHORTCUT_GESTURE_PINCH, "GTK_SHORTCUT_GESTURE_PINCH", "gesture-pinch" },
        { GTK_SHORTCUT_GESTURE_STRETCH, "GTK_SHORTCUT_GESTURE_STRETCH", "gesture-stretch" },
        { GTK_SHORTCUT_GESTURE_ROTATE_CLOCKWISE, "GTK_SHORTCUT_GESTURE_ROTATE_CLOCKWISE", "gesture-rotate-clockwise" },
        { GTK_SHORTCUT_GESTURE_ROTATE_COUNTERCLOCKWISE, "GTK_SHORTCUT_GESTURE_ROTATE_COUNTERCLOCKWISE", "gesture-rotate-counterclockwise" },
        { GTK_SHORTCUT_GESTURE_TWO_FINGER_SWIPE_LEFT, "GTK_SHORTCUT_GESTURE_TWO_FINGER_SWIPE_LEFT", "gesture-two-finger-swipe-left" },
        { GTK_SHORTCUT_GESTURE_TWO_FINGER_SWIPE_RIGHT, "GTK_SHORTCUT_GESTURE_TWO_FINGER_SWIPE_RIGHT", "gesture-two-finger-swipe-right" },
        { GTK_SHORTCUT_GESTURE, "GTK_SHORTCUT_GESTURE", "gesture" },
        { GTK_SHORTCUT_GESTURE_SWIPE_LEFT, "GTK_SHORTCUT_GESTURE_SWIPE_LEFT", "gesture-swipe-left" },
        { GTK_SHORTCUT_GESTURE_SWIPE_RIGHT, "GTK_SHORTCUT_GESTURE_SWIPE_RIGHT", "gesture-swipe-right" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkShortcutType"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtksorter.h" */
GType
gtk_sorter_order_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_SORTER_ORDER_PARTIAL, "GTK_SORTER_ORDER_PARTIAL", "partial" },
        { GTK_SORTER_ORDER_NONE, "GTK_SORTER_ORDER_NONE", "none" },
        { GTK_SORTER_ORDER_TOTAL, "GTK_SORTER_ORDER_TOTAL", "total" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkSorterOrder"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_sorter_change_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_SORTER_CHANGE_DIFFERENT, "GTK_SORTER_CHANGE_DIFFERENT", "different" },
        { GTK_SORTER_CHANGE_INVERTED, "GTK_SORTER_CHANGE_INVERTED", "inverted" },
        { GTK_SORTER_CHANGE_LESS_STRICT, "GTK_SORTER_CHANGE_LESS_STRICT", "less-strict" },
        { GTK_SORTER_CHANGE_MORE_STRICT, "GTK_SORTER_CHANGE_MORE_STRICT", "more-strict" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkSorterChange"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkspinbutton.h" */
GType
gtk_spin_button_update_policy_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_UPDATE_ALWAYS, "GTK_UPDATE_ALWAYS", "always" },
        { GTK_UPDATE_IF_VALID, "GTK_UPDATE_IF_VALID", "if-valid" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkSpinButtonUpdatePolicy"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_spin_type_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_SPIN_STEP_FORWARD, "GTK_SPIN_STEP_FORWARD", "step-forward" },
        { GTK_SPIN_STEP_BACKWARD, "GTK_SPIN_STEP_BACKWARD", "step-backward" },
        { GTK_SPIN_PAGE_FORWARD, "GTK_SPIN_PAGE_FORWARD", "page-forward" },
        { GTK_SPIN_PAGE_BACKWARD, "GTK_SPIN_PAGE_BACKWARD", "page-backward" },
        { GTK_SPIN_HOME, "GTK_SPIN_HOME", "home" },
        { GTK_SPIN_END, "GTK_SPIN_END", "end" },
        { GTK_SPIN_USER_DEFINED, "GTK_SPIN_USER_DEFINED", "user-defined" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkSpinType"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkstack.h" */
GType
gtk_stack_transition_type_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_STACK_TRANSITION_TYPE_NONE, "GTK_STACK_TRANSITION_TYPE_NONE", "none" },
        { GTK_STACK_TRANSITION_TYPE_CROSSFADE, "GTK_STACK_TRANSITION_TYPE_CROSSFADE", "crossfade" },
        { GTK_STACK_TRANSITION_TYPE_SLIDE_RIGHT, "GTK_STACK_TRANSITION_TYPE_SLIDE_RIGHT", "slide-right" },
        { GTK_STACK_TRANSITION_TYPE_SLIDE_LEFT, "GTK_STACK_TRANSITION_TYPE_SLIDE_LEFT", "slide-left" },
        { GTK_STACK_TRANSITION_TYPE_SLIDE_UP, "GTK_STACK_TRANSITION_TYPE_SLIDE_UP", "slide-up" },
        { GTK_STACK_TRANSITION_TYPE_SLIDE_DOWN, "GTK_STACK_TRANSITION_TYPE_SLIDE_DOWN", "slide-down" },
        { GTK_STACK_TRANSITION_TYPE_SLIDE_LEFT_RIGHT, "GTK_STACK_TRANSITION_TYPE_SLIDE_LEFT_RIGHT", "slide-left-right" },
        { GTK_STACK_TRANSITION_TYPE_SLIDE_UP_DOWN, "GTK_STACK_TRANSITION_TYPE_SLIDE_UP_DOWN", "slide-up-down" },
        { GTK_STACK_TRANSITION_TYPE_OVER_UP, "GTK_STACK_TRANSITION_TYPE_OVER_UP", "over-up" },
        { GTK_STACK_TRANSITION_TYPE_OVER_DOWN, "GTK_STACK_TRANSITION_TYPE_OVER_DOWN", "over-down" },
        { GTK_STACK_TRANSITION_TYPE_OVER_LEFT, "GTK_STACK_TRANSITION_TYPE_OVER_LEFT", "over-left" },
        { GTK_STACK_TRANSITION_TYPE_OVER_RIGHT, "GTK_STACK_TRANSITION_TYPE_OVER_RIGHT", "over-right" },
        { GTK_STACK_TRANSITION_TYPE_UNDER_UP, "GTK_STACK_TRANSITION_TYPE_UNDER_UP", "under-up" },
        { GTK_STACK_TRANSITION_TYPE_UNDER_DOWN, "GTK_STACK_TRANSITION_TYPE_UNDER_DOWN", "under-down" },
        { GTK_STACK_TRANSITION_TYPE_UNDER_LEFT, "GTK_STACK_TRANSITION_TYPE_UNDER_LEFT", "under-left" },
        { GTK_STACK_TRANSITION_TYPE_UNDER_RIGHT, "GTK_STACK_TRANSITION_TYPE_UNDER_RIGHT", "under-right" },
        { GTK_STACK_TRANSITION_TYPE_OVER_UP_DOWN, "GTK_STACK_TRANSITION_TYPE_OVER_UP_DOWN", "over-up-down" },
        { GTK_STACK_TRANSITION_TYPE_OVER_DOWN_UP, "GTK_STACK_TRANSITION_TYPE_OVER_DOWN_UP", "over-down-up" },
        { GTK_STACK_TRANSITION_TYPE_OVER_LEFT_RIGHT, "GTK_STACK_TRANSITION_TYPE_OVER_LEFT_RIGHT", "over-left-right" },
        { GTK_STACK_TRANSITION_TYPE_OVER_RIGHT_LEFT, "GTK_STACK_TRANSITION_TYPE_OVER_RIGHT_LEFT", "over-right-left" },
        { GTK_STACK_TRANSITION_TYPE_ROTATE_LEFT, "GTK_STACK_TRANSITION_TYPE_ROTATE_LEFT", "rotate-left" },
        { GTK_STACK_TRANSITION_TYPE_ROTATE_RIGHT, "GTK_STACK_TRANSITION_TYPE_ROTATE_RIGHT", "rotate-right" },
        { GTK_STACK_TRANSITION_TYPE_ROTATE_LEFT_RIGHT, "GTK_STACK_TRANSITION_TYPE_ROTATE_LEFT_RIGHT", "rotate-left-right" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkStackTransitionType"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkstringfilter.h" */
GType
gtk_string_filter_match_mode_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_STRING_FILTER_MATCH_MODE_EXACT, "GTK_STRING_FILTER_MATCH_MODE_EXACT", "exact" },
        { GTK_STRING_FILTER_MATCH_MODE_SUBSTRING, "GTK_STRING_FILTER_MATCH_MODE_SUBSTRING", "substring" },
        { GTK_STRING_FILTER_MATCH_MODE_PREFIX, "GTK_STRING_FILTER_MATCH_MODE_PREFIX", "prefix" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkStringFilterMatchMode"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkstringsorter.h" */
GType
gtk_collation_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_COLLATION_NONE, "GTK_COLLATION_NONE", "none" },
        { GTK_COLLATION_UNICODE, "GTK_COLLATION_UNICODE", "unicode" },
        { GTK_COLLATION_FILENAME, "GTK_COLLATION_FILENAME", "filename" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkCollation"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtktextiter.h" */
GType
gtk_text_search_flags_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { GTK_TEXT_SEARCH_VISIBLE_ONLY, "GTK_TEXT_SEARCH_VISIBLE_ONLY", "visible-only" },
        { GTK_TEXT_SEARCH_TEXT_ONLY, "GTK_TEXT_SEARCH_TEXT_ONLY", "text-only" },
        { GTK_TEXT_SEARCH_CASE_INSENSITIVE, "GTK_TEXT_SEARCH_CASE_INSENSITIVE", "case-insensitive" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_flags_register_static (g_intern_static_string ("GtkTextSearchFlags"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtktextview.h" */
GType
gtk_text_window_type_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_TEXT_WINDOW_WIDGET, "GTK_TEXT_WINDOW_WIDGET", "widget" },
        { GTK_TEXT_WINDOW_TEXT, "GTK_TEXT_WINDOW_TEXT", "text" },
        { GTK_TEXT_WINDOW_LEFT, "GTK_TEXT_WINDOW_LEFT", "left" },
        { GTK_TEXT_WINDOW_RIGHT, "GTK_TEXT_WINDOW_RIGHT", "right" },
        { GTK_TEXT_WINDOW_TOP, "GTK_TEXT_WINDOW_TOP", "top" },
        { GTK_TEXT_WINDOW_BOTTOM, "GTK_TEXT_WINDOW_BOTTOM", "bottom" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkTextWindowType"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_text_view_layer_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_TEXT_VIEW_LAYER_BELOW_TEXT, "GTK_TEXT_VIEW_LAYER_BELOW_TEXT", "below-text" },
        { GTK_TEXT_VIEW_LAYER_ABOVE_TEXT, "GTK_TEXT_VIEW_LAYER_ABOVE_TEXT", "above-text" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkTextViewLayer"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_text_extend_selection_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_TEXT_EXTEND_SELECTION_WORD, "GTK_TEXT_EXTEND_SELECTION_WORD", "word" },
        { GTK_TEXT_EXTEND_SELECTION_LINE, "GTK_TEXT_EXTEND_SELECTION_LINE", "line" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkTextExtendSelection"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
/* enumerations from "gtkprintoperation.h" */
GType
gtk_print_status_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_PRINT_STATUS_INITIAL, "GTK_PRINT_STATUS_INITIAL", "initial" },
        { GTK_PRINT_STATUS_PREPARING, "GTK_PRINT_STATUS_PREPARING", "preparing" },
        { GTK_PRINT_STATUS_GENERATING_DATA, "GTK_PRINT_STATUS_GENERATING_DATA", "generating-data" },
        { GTK_PRINT_STATUS_SENDING_DATA, "GTK_PRINT_STATUS_SENDING_DATA", "sending-data" },
        { GTK_PRINT_STATUS_PENDING, "GTK_PRINT_STATUS_PENDING", "pending" },
        { GTK_PRINT_STATUS_PENDING_ISSUE, "GTK_PRINT_STATUS_PENDING_ISSUE", "pending-issue" },
        { GTK_PRINT_STATUS_PRINTING, "GTK_PRINT_STATUS_PRINTING", "printing" },
        { GTK_PRINT_STATUS_FINISHED, "GTK_PRINT_STATUS_FINISHED", "finished" },
        { GTK_PRINT_STATUS_FINISHED_ABORTED, "GTK_PRINT_STATUS_FINISHED_ABORTED", "finished-aborted" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkPrintStatus"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_print_operation_result_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_PRINT_OPERATION_RESULT_ERROR, "GTK_PRINT_OPERATION_RESULT_ERROR", "error" },
        { GTK_PRINT_OPERATION_RESULT_APPLY, "GTK_PRINT_OPERATION_RESULT_APPLY", "apply" },
        { GTK_PRINT_OPERATION_RESULT_CANCEL, "GTK_PRINT_OPERATION_RESULT_CANCEL", "cancel" },
        { GTK_PRINT_OPERATION_RESULT_IN_PROGRESS, "GTK_PRINT_OPERATION_RESULT_IN_PROGRESS", "in-progress" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkPrintOperationResult"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_print_operation_action_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_PRINT_OPERATION_ACTION_PRINT_DIALOG, "GTK_PRINT_OPERATION_ACTION_PRINT_DIALOG", "print-dialog" },
        { GTK_PRINT_OPERATION_ACTION_PRINT, "GTK_PRINT_OPERATION_ACTION_PRINT", "print" },
        { GTK_PRINT_OPERATION_ACTION_PREVIEW, "GTK_PRINT_OPERATION_ACTION_PREVIEW", "preview" },
        { GTK_PRINT_OPERATION_ACTION_EXPORT, "GTK_PRINT_OPERATION_ACTION_EXPORT", "export" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkPrintOperationAction"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
GType
gtk_print_error_get_type (void)
{
  static gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { GTK_PRINT_ERROR_GENERAL, "GTK_PRINT_ERROR_GENERAL", "general" },
        { GTK_PRINT_ERROR_INTERNAL_ERROR, "GTK_PRINT_ERROR_INTERNAL_ERROR", "internal-error" },
        { GTK_PRINT_ERROR_NOMEM, "GTK_PRINT_ERROR_NOMEM", "nomem" },
        { GTK_PRINT_ERROR_INVALID_FILE, "GTK_PRINT_ERROR_INVALID_FILE", "invalid-file" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("GtkPrintError"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}


/* Generated data ends here */

